# OZI.build CHANGELOG
## 2.3.11 (2025-08-27)


### Build system


* build: update setuptools_scm pin to allow 9.x — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`00e7c42`](https://github.com/OZI-Project/OZI.build/commit/00e7c4241308e447f706378b092ad12b6bd6eb9a))


### Unknown


* :hammer: update dependabot — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a21b83f`](https://github.com/OZI-Project/OZI.build/commit/a21b83f059594f77b81a4d72e421b08f3ba37e8f))

## 2.3.10 (2025-08-25)


### Bug fixes


* fix: specify meson version <1.9 — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`f122c1a`](https://github.com/OZI-Project/OZI.build/commit/f122c1a6404af1100faa42ebd29b22aa432dc284))


### Build system


* build(deps): bump OZI-Project/draft from 1.17.0 to 1.17.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.17.0 to 1.17.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/cabcb89f38f90863aa0217f0b4b2dba02262b004...4f3dcb71f8251f1e8238eb011aa12dd6a9020d23)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.17.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`007d2fd`](https://github.com/OZI-Project/OZI.build/commit/007d2fd3167b1b00e613a1cb4b5877bb9dd813d4))

* build(deps): bump OZI-Project/publish from 1.17.0 to 1.17.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.17.0 to 1.17.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/ed9bff22f51f8b70c47a326e1e73a48174a8c6d2...4f60b808859fd63bd4be3bb9cc3e34d7a14c3bf7)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.17.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`6f1c0b9`](https://github.com/OZI-Project/OZI.build/commit/6f1c0b9c3133330e346b0dfe4ad01e48740322f6))

* build(deps): bump OZI-Project/secure-release from 1.1.1 to 1.2.0

Bumps [OZI-Project/secure-release](https://github.com/ozi-project/secure-release) from 1.1.1 to 1.2.0.
- [Release notes](https://github.com/ozi-project/secure-release/releases)
- [Commits](https://github.com/ozi-project/secure-release/compare/f3b39775daaaf4190e0ee655a7bbd0aa55b8b166...2ef1b3f4b10f3fee22ba26444a6324203d6e2ea4)


updated-dependencies:
- dependency-name: OZI-Project/secure-release
  dependency-version: 1.2.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`930c8bb`](https://github.com/OZI-Project/OZI.build/commit/930c8bb5b2aa51eca7ea928e566ae6664da35bda))

* build(deps): bump actions/download-artifact from 4.3.0 to 5.0.0

Bumps [actions/download-artifact](https://github.com/actions/download-artifact) from 4.3.0 to 5.0.0.
- [Release notes](https://github.com/actions/download-artifact/releases)
- [Commits](https://github.com/actions/download-artifact/compare/d3f86a106a0bac45b974a628896c90dbdf5c8093...634f93cb2916e3fdff6788551b99b062d0335ce0)


updated-dependencies:
- dependency-name: actions/download-artifact
  dependency-version: 5.0.0
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`aa557f6`](https://github.com/OZI-Project/OZI.build/commit/aa557f6f08d17c4599e29cc138490f516c7fa3f0))

* build(deps): bump build from 1.2.2.post1 to 1.3.0 in /doc

Bumps [build](https://github.com/pypa/build) from 1.2.2.post1 to 1.3.0.
- [Release notes](https://github.com/pypa/build/releases)
- [Changelog](https://github.com/pypa/build/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pypa/build/compare/1.2.2.post1...1.3.0)


updated-dependencies:
- dependency-name: build
  dependency-version: 1.3.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`05261ee`](https://github.com/OZI-Project/OZI.build/commit/05261ee203524e2841edc74d10af04dd40a458dc))

* build(deps): bump pip-tools from 7.4.1 to 7.5.0 in /doc

Bumps [pip-tools](https://github.com/jazzband/pip-tools) from 7.4.1 to 7.5.0.
- [Release notes](https://github.com/jazzband/pip-tools/releases)
- [Changelog](https://github.com/jazzband/pip-tools/blob/main/CHANGELOG.md)
- [Commits](https://github.com/jazzband/pip-tools/compare/7.4.1...v7.5.0)


updated-dependencies:
- dependency-name: pip-tools
  dependency-version: 7.5.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a7a140b`](https://github.com/OZI-Project/OZI.build/commit/a7a140bf98b67bea983ba93e11d6dc748c8ee7df))

* build(deps): bump github/codeql-action from 3.29.7 to 3.29.11

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.29.7 to 3.29.11.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/51f77329afa6477de8c49fc9c7046c15b9a4e79d...3c3833e0f8c1c83d449a7478aa59c036a9165498)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.11
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8d0ebee`](https://github.com/OZI-Project/OZI.build/commit/8d0ebee9dcb8102bf0209a366c8abdacd276ea52))

* build(deps): bump charset-normalizer from 3.4.2 to 3.4.3 in /doc

Bumps [charset-normalizer](https://github.com/jawah/charset_normalizer) from 3.4.2 to 3.4.3.
- [Release notes](https://github.com/jawah/charset_normalizer/releases)
- [Changelog](https://github.com/jawah/charset_normalizer/blob/master/CHANGELOG.md)
- [Commits](https://github.com/jawah/charset_normalizer/compare/3.4.2...3.4.3)


updated-dependencies:
- dependency-name: charset-normalizer
  dependency-version: 3.4.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`254bec6`](https://github.com/OZI-Project/OZI.build/commit/254bec6ec32c09fdc4a20804a7898d7342567a7a))

## 2.3.9 (2025-08-08)


### Build system


* build(deps): bump pygments from 2.19.1 to 2.19.2 in /doc

Bumps [pygments](https://github.com/pygments/pygments) from 2.19.1 to 2.19.2.
- [Release notes](https://github.com/pygments/pygments/releases)
- [Changelog](https://github.com/pygments/pygments/blob/master/CHANGES)
- [Commits](https://github.com/pygments/pygments/compare/2.19.1...2.19.2)


updated-dependencies:
- dependency-name: pygments
  dependency-version: 2.19.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`505735d`](https://github.com/OZI-Project/OZI.build/commit/505735d67fcf717b8381b13da77da72968cff502))

* build(deps): bump urllib3 from 2.4.0 to 2.5.0 in /doc

Bumps [urllib3](https://github.com/urllib3/urllib3) from 2.4.0 to 2.5.0.
- [Release notes](https://github.com/urllib3/urllib3/releases)
- [Changelog](https://github.com/urllib3/urllib3/blob/main/CHANGES.rst)
- [Commits](https://github.com/urllib3/urllib3/compare/2.4.0...2.5.0)


updated-dependencies:
- dependency-name: urllib3
  dependency-version: 2.5.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a35ac2f`](https://github.com/OZI-Project/OZI.build/commit/a35ac2f2d503eb0e2d17fe898cf4ab6263b6984f))

* build(deps): bump gitpython from 3.1.44 to 3.1.45 in /doc

Bumps [gitpython](https://github.com/gitpython-developers/GitPython) from 3.1.44 to 3.1.45.
- [Release notes](https://github.com/gitpython-developers/GitPython/releases)
- [Changelog](https://github.com/gitpython-developers/GitPython/blob/main/CHANGES)
- [Commits](https://github.com/gitpython-developers/GitPython/compare/3.1.44...3.1.45)


updated-dependencies:
- dependency-name: gitpython
  dependency-version: 3.1.45
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b7ed5fb`](https://github.com/OZI-Project/OZI.build/commit/b7ed5fb0cc518404102d420d7c35c358e99e079b))

* build(deps): bump certifi from 2025.6.15 to 2025.8.3 in /doc

Bumps [certifi](https://github.com/certifi/python-certifi) from 2025.6.15 to 2025.8.3.
- [Commits](https://github.com/certifi/python-certifi/compare/2025.06.15...2025.08.03)


updated-dependencies:
- dependency-name: certifi
  dependency-version: 2025.8.3
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`934a1d2`](https://github.com/OZI-Project/OZI.build/commit/934a1d255f1f32cfffc439b7213e205524401022))

* build(deps): bump step-security/harden-runner from 2.12.2 to 2.13.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.12.2 to 2.13.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/6c439dc8bdf85cadbbce9ed30d1c7b959517bc49...ec9f2d5744a09debf3a187a3f4f675c53b671911)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.13.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b63e8d0`](https://github.com/OZI-Project/OZI.build/commit/b63e8d0c01ee7bb0fd1326a5663e77ad23b90334))

* build(deps): bump OZI-Project/checkpoint from 1.9.1 to 1.9.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.9.1 to 1.9.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/b7afe55ac890df008deb75191e53f83823117f92...f475dbf6078211f784f6e7b3bb7c1b00ce0d05b9)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.9.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7093b76`](https://github.com/OZI-Project/OZI.build/commit/7093b7631fc71f7514fa0278e36a0dfee39c7629))

* build(deps): bump OZI-Project/publish from 1.15.0 to 1.17.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.15.0 to 1.17.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/c448915d89a76028ab54f2b539ad159e3a612003...ed9bff22f51f8b70c47a326e1e73a48174a8c6d2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.17.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`418590e`](https://github.com/OZI-Project/OZI.build/commit/418590ed77a6e12c0b118a8f8124434c99063ebd))

* build(deps): bump OZI-Project/draft from 1.15.0 to 1.17.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.15.0 to 1.17.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/4f9117750cd22709a929ed3f36578f172a94bd41...cabcb89f38f90863aa0217f0b4b2dba02262b004)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.17.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a1e37bd`](https://github.com/OZI-Project/OZI.build/commit/a1e37bd1842988d6a8b850bdb6f0e03d2173c3dc))

* build(deps-dev): bump uv in the pip group across 1 directory

Bumps the pip group with 1 update in the / directory: [uv](https://github.com/astral-sh/uv).


Updates `uv` from 0.5.14 to 0.8.6
- [Release notes](https://github.com/astral-sh/uv/releases)
- [Changelog](https://github.com/astral-sh/uv/blob/main/CHANGELOG.md)
- [Commits](https://github.com/astral-sh/uv/compare/0.5.14...0.8.6)


updated-dependencies:
- dependency-name: uv
  dependency-version: 0.8.6
  dependency-type: direct:development
  dependency-group: pip
... — dependabot[bot] <support@github.com>
([`1e49dbf`](https://github.com/OZI-Project/OZI.build/commit/1e49dbfc432960d80d751b8a0a9fd2481044025a))

* build(deps): bump github/codeql-action from 3.29.2 to 3.29.7

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.29.2 to 3.29.7.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/181d5eefc20863364f96762470ba6f862bdef56b...51f77329afa6477de8c49fc9c7046c15b9a4e79d)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9acd7e8`](https://github.com/OZI-Project/OZI.build/commit/9acd7e80670213a52d69eb8381384156963cf4cc))

* build(deps): bump sphinx-sitemap from 2.6.0 to 2.7.2 in /doc

Bumps [sphinx-sitemap](https://github.com/jdillard/sphinx-sitemap) from 2.6.0 to 2.7.2.
- [Release notes](https://github.com/jdillard/sphinx-sitemap/releases)
- [Changelog](https://github.com/jdillard/sphinx-sitemap/blob/master/CHANGELOG.rst)
- [Commits](https://github.com/jdillard/sphinx-sitemap/compare/v2.6.0...v2.7.2)


updated-dependencies:
- dependency-name: sphinx-sitemap
  dependency-version: 2.7.2
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`da57d30`](https://github.com/OZI-Project/OZI.build/commit/da57d306190c7b3eaa10d765e2567937a369e5e6))

* build(deps): bump github/codeql-action from 3.29.0 to 3.29.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.29.0 to 3.29.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ce28f5bb42b7a9f2c824e633a3f6ee835bab6858...181d5eefc20863364f96762470ba6f862bdef56b)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`0f5653a`](https://github.com/OZI-Project/OZI.build/commit/0f5653ac2051a092e7ef742a1841e572f2e82bd8))

* build(deps): bump step-security/harden-runner from 2.12.1 to 2.12.2

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.12.1 to 2.12.2.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/002fdce3c6a235733a90a27c80493a3241e56863...6c439dc8bdf85cadbbce9ed30d1c7b959517bc49)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.12.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c1d5791`](https://github.com/OZI-Project/OZI.build/commit/c1d57911c7f7a73fa30f303231b1de436e65fb1f))

## 2.3.8 (2025-06-18)


### Build system


* build: add tag input to provenance step — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`c59f929`](https://github.com/OZI-Project/OZI.build/commit/c59f9295268dae163fdc7dd3351481bacfbd566f))

* build(deps): bump OZI-Project/provenance from 0.0.6 to 0.1.0

Bumps [OZI-Project/provenance](https://github.com/ozi-project/provenance) from 0.0.6 to 0.1.0.
- [Release notes](https://github.com/ozi-project/provenance/releases)
- [Commits](https://github.com/ozi-project/provenance/compare/807f918ec5362a827c4230d041bb9847b25ce7cd...a7369a6ef4a56f442b97615539b8de23dcb1e94e)


updated-dependencies:
- dependency-name: OZI-Project/provenance
  dependency-version: 0.1.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c89dfa2`](https://github.com/OZI-Project/OZI.build/commit/c89dfa20d3042e9462befc518fe9ba5ccb34e73c))

## 2.3.7 (2025-06-17)


### Build system


* build(deps): bump OZI-Project/provenance from 0.0.5 to 0.0.6

Bumps [OZI-Project/provenance](https://github.com/ozi-project/provenance) from 0.0.5 to 0.0.6.
- [Release notes](https://github.com/ozi-project/provenance/releases)
- [Commits](https://github.com/ozi-project/provenance/compare/34d637e8613f1e6abafe0f7586174d26e048ed44...807f918ec5362a827c4230d041bb9847b25ce7cd)


updated-dependencies:
- dependency-name: OZI-Project/provenance
  dependency-version: 0.0.6
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d086685`](https://github.com/OZI-Project/OZI.build/commit/d0866855c90ff079b8ff780051d2e839fa40b0c9))

## 2.3.6 (2025-06-17)


### Build system


* build(deps): bump OZI-Project/provenance from 0.0.4 to 0.0.5

Bumps [OZI-Project/provenance](https://github.com/ozi-project/provenance) from 0.0.4 to 0.0.5.
- [Release notes](https://github.com/ozi-project/provenance/releases)
- [Commits](https://github.com/ozi-project/provenance/compare/bcce6236bdc65a70f3c1973c9945c96545fba46f...34d637e8613f1e6abafe0f7586174d26e048ed44)


updated-dependencies:
- dependency-name: OZI-Project/provenance
  dependency-version: 0.0.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f0573a5`](https://github.com/OZI-Project/OZI.build/commit/f0573a5e9063da0c2fc7c696be401bd74b060851))

## 2.3.5 (2025-06-17)


### Build system


* build(deps): bump OZI-Project/provenance from 0.0.3 to 0.0.4

Bumps [OZI-Project/provenance](https://github.com/ozi-project/provenance) from 0.0.3 to 0.0.4.
- [Release notes](https://github.com/ozi-project/provenance/releases)
- [Commits](https://github.com/ozi-project/provenance/compare/97de2d68348340fbb214f852de3a527e323d2a57...bcce6236bdc65a70f3c1973c9945c96545fba46f)


updated-dependencies:
- dependency-name: OZI-Project/provenance
  dependency-version: 0.0.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2fcb5d0`](https://github.com/OZI-Project/OZI.build/commit/2fcb5d0623a844a0f47eae1d0a4b61138143d92d))

* build(ci): Harden GitHub Actions — StepSecurity Bot <bot@stepsecurity.io>
([`65425a8`](https://github.com/OZI-Project/OZI.build/commit/65425a8cbc9bfbb5187f7cc8aea0d4349c99e7ac))

## 2.3.4 (2025-06-17)


### Build system


* build: use the new provenance workflow — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`a8eb042`](https://github.com/OZI-Project/OZI.build/commit/a8eb04221279366310c9d8f31d32b1a9f483a3b0))

## 2.3.3 (2025-06-15)


### Bug fixes


* fix: get_platform_tag() uses sysconfig — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`b2ee480`](https://github.com/OZI-Project/OZI.build/commit/b2ee48036f5b2125b990b2ce91a7685a04d99f43))


### Build system


* build(deps): bump github/codeql-action from 3.28.19 to 3.29.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.19 to 3.29.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/fca7ace96b7d713c7035871441bd52efbe39e27e...ce28f5bb42b7a9f2c824e633a3f6ee835bab6858)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.29.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`541ae73`](https://github.com/OZI-Project/OZI.build/commit/541ae73488e2caaefaad00cfcfb10d131a352eed))

* build(deps): bump OZI-Project/draft from 1.14.2 to 1.15.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.14.2 to 1.15.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/d870c506fefd49de075e21217885c8670cd9b883...4f9117750cd22709a929ed3f36578f172a94bd41)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.15.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f09dfe6`](https://github.com/OZI-Project/OZI.build/commit/f09dfe6665a5c5134faa4bc6d004427beaef2db3))

* build(deps): bump OZI-Project/publish from 1.14.3 to 1.15.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.14.3 to 1.15.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/d2deb87a158a3555d67cb9dbabde2fe3e271fa6a...c448915d89a76028ab54f2b539ad159e3a612003)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.15.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`532c220`](https://github.com/OZI-Project/OZI.build/commit/532c220be4c8b067948a6a536244d98cebd2f4d6))

* build(deps): bump step-security/harden-runner from 2.12.0 to 2.12.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.12.0 to 2.12.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0634a2670c59f64b4a01f0f96f84700a4088b9f0...002fdce3c6a235733a90a27c80493a3241e56863)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.12.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9e5d3b1`](https://github.com/OZI-Project/OZI.build/commit/9e5d3b134dfbe88647bf5e467aedb522b9c47850))

* build(deps): bump certifi from 2025.4.26 to 2025.6.15 in /doc

Bumps [certifi](https://github.com/certifi/python-certifi) from 2025.4.26 to 2025.6.15.
- [Commits](https://github.com/certifi/python-certifi/compare/2025.04.26...2025.06.15)


updated-dependencies:
- dependency-name: certifi
  dependency-version: 2025.6.15
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`2c71e5e`](https://github.com/OZI-Project/OZI.build/commit/2c71e5ef5c87f95a981b37569bbd36a853ca7d75))

* build(deps): bump OZI-Project/checkpoint from 1.8.3 to 1.9.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.8.3 to 1.9.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/34c59f4977fed722934fae2caadc29e3f0f8bf0d...b7afe55ac890df008deb75191e53f83823117f92)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.9.1
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`df025a4`](https://github.com/OZI-Project/OZI.build/commit/df025a4fc60e8a51bc10f58c13673551e2f3110e))


### Chores


* chore: delete requirements.txt — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`4a55e71`](https://github.com/OZI-Project/OZI.build/commit/4a55e711bf644c70260be532e5ebfac5ff4d91f0))

* chore: delete .gitlab-ci.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`cd6ba37`](https://github.com/OZI-Project/OZI.build/commit/cd6ba3724023305aba3fcfaa1439d2e9fa3c05d0))

* chore: delete .codeclimate.yml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`27c9b0d`](https://github.com/OZI-Project/OZI.build/commit/27c9b0dd080551891f0bb760adcb2658f3f774a8))

## 2.3.2 (2025-06-10)


### Bug fixes


* fix: broken pep425tags import in _util.GET_CHECK — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`d13d140`](https://github.com/OZI-Project/OZI.build/commit/d13d1407e24c9090d8d6c5b1e31ffc56cb8fc42a))


### Build system


* build(deps): update ozi-build requirement from ~=2.2 to ~=2.3 in /doc

Updates the requirements on [ozi-build](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/2.2.0...2.3.0)


updated-dependencies:
- dependency-name: ozi-build
  dependency-version: 2.3.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`641aaf5`](https://github.com/OZI-Project/OZI.build/commit/641aaf5d5f4a99bacad5814e8034d5f3f2f00e4b))

* build(deps): bump OZI-Project/checkpoint from 1.7.5 to 1.8.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.5 to 1.8.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/301753e6853d6a65055c8df69dafe7df74bd7963...34c59f4977fed722934fae2caadc29e3f0f8bf0d)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.8.3
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`8fba79b`](https://github.com/OZI-Project/OZI.build/commit/8fba79b1ff6ba5ffe0ca2a2246d1dd78ee4539e2))

* build(deps): bump requests from 2.32.3 to 2.32.4 in /doc

Bumps [requests](https://github.com/psf/requests) from 2.32.3 to 2.32.4.
- [Release notes](https://github.com/psf/requests/releases)
- [Changelog](https://github.com/psf/requests/blob/main/HISTORY.md)
- [Commits](https://github.com/psf/requests/compare/v2.32.3...v2.32.4)


updated-dependencies:
- dependency-name: requests
  dependency-version: 2.32.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e5b9285`](https://github.com/OZI-Project/OZI.build/commit/e5b9285579ed2c0cf784c395f57cf35fa9b408be))

* build(deps): bump meson[ninja] from 1.8.1 to 1.8.2 in /doc

Bumps [meson[ninja]](https://github.com/mesonbuild/meson) from 1.8.1 to 1.8.2.
- [Release notes](https://github.com/mesonbuild/meson/releases)
- [Commits](https://github.com/mesonbuild/meson/compare/1.8.1...1.8.2)


updated-dependencies:
- dependency-name: meson[ninja]
  dependency-version: 1.8.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`151ad07`](https://github.com/OZI-Project/OZI.build/commit/151ad07d3a940c552e4330f7c16a080f80dac544))


### Chores


* chore: ozi patches — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`709b8ae`](https://github.com/OZI-Project/OZI.build/commit/709b8aeba1436515f38adb75db34bcecd9f2c7a8))

* chore: update ozi.wrap — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`9118a77`](https://github.com/OZI-Project/OZI.build/commit/9118a7768a1dc29bde7af29e9b84873c975dd3f0))

## 2.3.1 (2025-06-06)


### Bug fixes


* fix: correct major.minor version in pyproject.toml — Eden Ross Duff, MSc <ozi.project@outlook.com>
([`c13e4d6`](https://github.com/OZI-Project/OZI.build/commit/c13e4d63510a0aab23600b63a699520a834b8985))

* fix: missing wheel module meson.build — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`aaccaa8`](https://github.com/OZI-Project/OZI.build/commit/aaccaa8168290d87c3caeb3eb79936a4a45ce287))

* fix: wheel submodule was missing — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`5446b84`](https://github.com/OZI-Project/OZI.build/commit/5446b8480d909cd1c8e91ecf86ca9d287d1962a9))


### Chores


* chore: noqa vendored wheelfile — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`c9248cc`](https://github.com/OZI-Project/OZI.build/commit/c9248cc21fcef38e41ff75cc77889ce3c955c145))

## 2.3.0 (2025-06-05)


### Chores


* chore: run isort — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`6063923`](https://github.com/OZI-Project/OZI.build/commit/6063923630956c3aa401dc6fc8bdd5197b63c5a1))

## 2.2.3 (2025-05-25)


### Bug fixes


* fix: config_settings = None caused error in build_wheel — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`21dd9d0`](https://github.com/OZI-Project/OZI.build/commit/21dd9d0d93fb9afb8157f6af2843b22d43fcf68a))

* fix: create pull request job (#350) — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`6a53bd9`](https://github.com/OZI-Project/OZI.build/commit/6a53bd93c8657ab357b558b4389d2a6c042ac20f))


### Build system


* build(deps): bump meson[ninja] from 1.7.2 to 1.8.1 in /doc

Bumps [meson[ninja]](https://github.com/mesonbuild/meson) from 1.7.2 to 1.8.1.
- [Release notes](https://github.com/mesonbuild/meson/releases)
- [Commits](https://github.com/mesonbuild/meson/compare/1.7.2...1.8.1)


updated-dependencies:
- dependency-name: meson[ninja]
  dependency-version: 1.8.1
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4992b60`](https://github.com/OZI-Project/OZI.build/commit/4992b604af6d9c3f00935a656d099b07c2d9f41f))

* build(deps): bump ossf/scorecard-action from 2.4.1 to 2.4.2

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.4.1 to 2.4.2.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/f49aabe0b5af0936a0987cfb85d86b75731b0186...05b42c624433fc40578a4040d5cf5e36ddca8cde)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-version: 2.4.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`046a062`](https://github.com/OZI-Project/OZI.build/commit/046a062887c50b25ba8611e23cd4e0a26340c116))

* build(deps): bump OZI-Project/checkpoint from 1.7.3 to 1.7.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.3 to 1.7.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/1b0b165711dca7c852f4c30fbebea96de3747617...301753e6853d6a65055c8df69dafe7df74bd7963)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`0a1ba69`](https://github.com/OZI-Project/OZI.build/commit/0a1ba69a99b667d5b71a03fa964df38f1226878f))

* build(deps): bump OZI-Project/draft from 1.13.4 to 1.14.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.4 to 1.14.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/84f054f0398fe815ac68f4243f6aafb9f5b85e4a...d870c506fefd49de075e21217885c8670cd9b883)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.14.2
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`9ee5d28`](https://github.com/OZI-Project/OZI.build/commit/9ee5d2848ba55266cd67fc2ecb1ccf75d2f23e96))

* build(deps): bump github/codeql-action from 3.28.18 to 3.28.19

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.18 to 3.28.19.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ff0a06e83cb2de871e5a09832bc6a81e7276941f...fca7ace96b7d713c7035871441bd52efbe39e27e)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.19
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e828229`](https://github.com/OZI-Project/OZI.build/commit/e828229811cb543adbeb3a1a0d6cca5eeb759c5d))

* build(deps): bump OZI-Project/publish from 1.13.7 to 1.14.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.7 to 1.14.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/621f1f7d2691300b8a66b0aaa62a4853359daa89...d2deb87a158a3555d67cb9dbabde2fe3e271fa6a)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.14.3
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`04a7283`](https://github.com/OZI-Project/OZI.build/commit/04a72833415cffec9e78db285595a9c4f7fde456))

* build(deps): bump setuptools in the pip group across 1 directory

Bumps the pip group with 1 update in the / directory: [setuptools](https://github.com/pypa/setuptools).


Updates `setuptools` from 75.6.0 to 78.1.1
- [Release notes](https://github.com/pypa/setuptools/releases)
- [Changelog](https://github.com/pypa/setuptools/blob/main/NEWS.rst)
- [Commits](https://github.com/pypa/setuptools/compare/v75.6.0...v78.1.1)


updated-dependencies:
- dependency-name: setuptools
  dependency-version: 78.1.1
  dependency-type: direct:production
  dependency-group: pip
... — dependabot[bot] <support@github.com>
([`0aa9063`](https://github.com/OZI-Project/OZI.build/commit/0aa90632e4136a096b0efe04b70cde9a83534c68))

* build(deps): bump OZI-Project/secure-release from 1.1.0 to 1.1.1

Bumps [OZI-Project/secure-release](https://github.com/ozi-project/secure-release) from 1.1.0 to 1.1.1.
- [Release notes](https://github.com/ozi-project/secure-release/releases)
- [Commits](https://github.com/ozi-project/secure-release/compare/1.1.0...1.1.1)


updated-dependencies:
- dependency-name: OZI-Project/secure-release
  dependency-version: 1.1.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`911a080`](https://github.com/OZI-Project/OZI.build/commit/911a08000603dc30567af3fb397440fa379f3bf7))

* build(deps): bump github/codeql-action from 3.28.17 to 3.28.18

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.17 to 3.28.18.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/60168efe1c415ce0f5521ea06d5c2062adbeed1b...ff0a06e83cb2de871e5a09832bc6a81e7276941f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.18
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9596cd4`](https://github.com/OZI-Project/OZI.build/commit/9596cd4ebc57005b94b5f612071b42c8255295f9))

* build(deps): bump actions/dependency-review-action from 4.7.0 to 4.7.1

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.7.0 to 4.7.1.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/38ecb5b593bf0eb19e335c03f97670f792489a8b...da24556b548a50705dd671f47852072ea4c105d9)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.7.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e21ea0b`](https://github.com/OZI-Project/OZI.build/commit/e21ea0bca24f6b75e47b35391b88fc868660efc3))

* build(deps): bump OZI-Project/secure-release from 1.0.7 to 1.1.0

Bumps [OZI-Project/secure-release](https://github.com/ozi-project/secure-release) from 1.0.7 to 1.1.0.
- [Release notes](https://github.com/ozi-project/secure-release/releases)
- [Commits](https://github.com/ozi-project/secure-release/compare/1.0.7...1.1.0)


updated-dependencies:
- dependency-name: OZI-Project/secure-release
  dependency-version: 1.1.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c3f8639`](https://github.com/OZI-Project/OZI.build/commit/c3f8639e67e330ba1bad0a66d25fad4d08a3fcf9))


### Chores


* chore: run black — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`1ebe66c`](https://github.com/OZI-Project/OZI.build/commit/1ebe66cf7e498f118dd042d84e73160c9c9b9c1e))


### Features


* feat: improved module structure for vendored tools — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`7a032f9`](https://github.com/OZI-Project/OZI.build/commit/7a032f95f288852962c1cbb46ef78707e956746a))

## 2.2.2 (2025-05-13)


### Build system


* build: ozi.wrap 1.41.9 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`fe89f5c`](https://github.com/OZI-Project/OZI.build/commit/fe89f5ca751453f5927af51ec0ae9cf3737cbc89))

* build(deps): bump OZI-Project/secure-release from 1.0.6 to 1.0.7

Bumps [OZI-Project/secure-release](https://github.com/ozi-project/secure-release) from 1.0.6 to 1.0.7.
- [Release notes](https://github.com/ozi-project/secure-release/releases)
- [Commits](https://github.com/ozi-project/secure-release/compare/1.0.6...1.0.7)


updated-dependencies:
- dependency-name: OZI-Project/secure-release
  dependency-version: 1.0.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`14c2a24`](https://github.com/OZI-Project/OZI.build/commit/14c2a2437afe42440b01a9a7a3e2fd29b718f928))

* build(deps): bump OZI-Project/secure-release from 1.0.5 to 1.0.6

Bumps [OZI-Project/secure-release](https://github.com/ozi-project/secure-release) from 1.0.5 to 1.0.6.
- [Release notes](https://github.com/ozi-project/secure-release/releases)
- [Commits](https://github.com/ozi-project/secure-release/compare/1.0.5...1.0.6)


updated-dependencies:
- dependency-name: OZI-Project/secure-release
  dependency-version: 1.0.6
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a7f58a4`](https://github.com/OZI-Project/OZI.build/commit/a7f58a4ce98c3abb9f08879e6aae904e7b2ed961))

* build: ozi.wrap 1.41.8 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`0654211`](https://github.com/OZI-Project/OZI.build/commit/0654211b969fd418d4bdbb85aa14d78aee8ebc2a))

* build(deps): bump OZI-Project/secure-release from 1.0.4 to 1.0.5

Bumps [OZI-Project/secure-release](https://github.com/ozi-project/secure-release) from 1.0.4 to 1.0.5.
- [Release notes](https://github.com/ozi-project/secure-release/releases)
- [Commits](https://github.com/ozi-project/secure-release/compare/1.0.4...1.0.5)


updated-dependencies:
- dependency-name: OZI-Project/secure-release
  dependency-version: 1.0.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ce6cd12`](https://github.com/OZI-Project/OZI.build/commit/ce6cd12eec47a1492ab73033a0217ac23fed00f1))

* build: ozi.wrap 1.41.7 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`29e814d`](https://github.com/OZI-Project/OZI.build/commit/29e814da78b5d92f4a8a44ed420cecd4fa7053af))

* build: update ozi.wrap to 1.41.6 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`d4f9845`](https://github.com/OZI-Project/OZI.build/commit/d4f9845a4a0453e2e55c8d2b12ac6b09ce797e68))

* build(deps): bump OZI-Project/secure-release from 1.0.3 to 1.0.4

Bumps [OZI-Project/secure-release](https://github.com/ozi-project/secure-release) from 1.0.3 to 1.0.4.
- [Release notes](https://github.com/ozi-project/secure-release/releases)
- [Commits](https://github.com/ozi-project/secure-release/compare/1.0.3...1.0.4)


updated-dependencies:
- dependency-name: OZI-Project/secure-release
  dependency-version: 1.0.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`121bf21`](https://github.com/OZI-Project/OZI.build/commit/121bf21650cc3d1e9a4d4b97a27b8ceea96ccb79))

* build: init invoke tox env before release publish — Eden Ross Duff, MSc, DDiv <ozi.project@outlook.com>
([`d949493`](https://github.com/OZI-Project/OZI.build/commit/d9494937461eb0c9aead5b058488c2c073e3b9d5))

* build(deps): bump OZI-Project/secure-release from 1.0.2 to 1.0.3

Bumps [OZI-Project/secure-release](https://github.com/ozi-project/secure-release) from 1.0.2 to 1.0.3.
- [Release notes](https://github.com/ozi-project/secure-release/releases)
- [Commits](https://github.com/ozi-project/secure-release/compare/1.0.2...1.0.3)


updated-dependencies:
- dependency-name: OZI-Project/secure-release
  dependency-version: 1.0.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b3a813d`](https://github.com/OZI-Project/OZI.build/commit/b3a813d68c710cffba6df503d3b2a9dc5b5fd7df))

* build(deps): bump OZI-Project/secure-release from 1.0.1 to 1.0.2

Bumps [OZI-Project/secure-release](https://github.com/ozi-project/secure-release) from 1.0.1 to 1.0.2.
- [Release notes](https://github.com/ozi-project/secure-release/releases)
- [Commits](https://github.com/ozi-project/secure-release/compare/1.0.1...1.0.2)


updated-dependencies:
- dependency-name: OZI-Project/secure-release
  dependency-version: 1.0.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c181313`](https://github.com/OZI-Project/OZI.build/commit/c181313ce005ea76959546e801d92ea68f523ce7))

* build(deps): bump OZI-Project/secure-release from 1.0.0 to 1.0.1

Bumps [OZI-Project/secure-release](https://github.com/ozi-project/secure-release) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/secure-release/releases)
- [Commits](https://github.com/ozi-project/secure-release/compare/1.0.0...1.0.1)


updated-dependencies:
- dependency-name: OZI-Project/secure-release
  dependency-version: 1.0.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a74bc5a`](https://github.com/OZI-Project/OZI.build/commit/a74bc5a7ab9b09aade1203df8f730d8664f75ea4))

* build: use secure-release action — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`a57657f`](https://github.com/OZI-Project/OZI.build/commit/a57657fddfd48099ac0e1fe6315cdbca19fa0a46))

* build(deps): update ozi-build requirement from ~=2.1 to ~=2.2 in /doc

Updates the requirements on [ozi-build](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/2.1.0...2.2.1)


updated-dependencies:
- dependency-name: ozi-build
  dependency-version: 2.2.1
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`0c6582a`](https://github.com/OZI-Project/OZI.build/commit/0c6582ad2ecfc390ae847bf5a1342b188239a8e1))

* build(deps): bump snowballstemmer from 3.0.0.1 to 3.0.1 in /doc

Bumps [snowballstemmer](https://github.com/snowballstem/snowball) from 3.0.0.1 to 3.0.1.
- [Changelog](https://github.com/snowballstem/snowball/blob/master/NEWS)
- [Commits](https://github.com/snowballstem/snowball/commits/v3.0.1)


updated-dependencies:
- dependency-name: snowballstemmer
  dependency-version: 3.0.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`bf3627a`](https://github.com/OZI-Project/OZI.build/commit/bf3627a01cd56dd6af181977ae16d9e35ec25f14))

* build(deps): bump OZI-Project/draft from 1.13.3 to 1.13.4

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.3 to 1.13.4.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/68b9a0082a1e1fafa581b7cb6488254df5f47a39...84f054f0398fe815ac68f4243f6aafb9f5b85e4a)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f36d031`](https://github.com/OZI-Project/OZI.build/commit/f36d0311ced8f9e28a8a874a04eca24592d5a65d))

* build(deps): bump OZI-Project/publish from 1.13.5 to 1.13.7

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.5 to 1.13.7.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/2db0b4c8cd2073e42b9aa5f399020b78cfee31e0...621f1f7d2691300b8a66b0aaa62a4853359daa89)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.7
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`90d75ab`](https://github.com/OZI-Project/OZI.build/commit/90d75abedc1d1ab8a5e3f6b8005d51ce3286badf))

* build(deps): bump OZI-Project/checkpoint from 1.7.2 to 1.7.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.2 to 1.7.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/ac9e45ece7eecacce1a9acb44ae4443985fe310b...1b0b165711dca7c852f4c30fbebea96de3747617)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b902085`](https://github.com/OZI-Project/OZI.build/commit/b902085967900248634d9ff3287a8351357ab6ef))

* build: fix workflow injectable logic — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`d0f3cb2`](https://github.com/OZI-Project/OZI.build/commit/d0f3cb20c1625742686596f85e60858fb2ab215d))

## 2.2.1 (2025-05-09)


### Bug fixes


* fix: formatting — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`f18bf20`](https://github.com/OZI-Project/OZI.build/commit/f18bf20ad4e4f2318fa01bc84b1a99f13a8f4380))

* fix: expect UTF-8 encoded WHEEL_SIGN_TOKEN — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`37636f9`](https://github.com/OZI-Project/OZI.build/commit/37636f92b2bf817fc146114586685f6ca261bc01))

* fix: add pass_env WHEEL_SIGN_TOKEN to tox invoke config — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`9558317`](https://github.com/OZI-Project/OZI.build/commit/9558317cca9748faaac5b3efd535276803cfe1a8))

* fix: convert WHEEL_SIGN_TOKEN to bytes — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`8f45421`](https://github.com/OZI-Project/OZI.build/commit/8f45421d8dbc4b273bae42c65613901d4109eeaa))

* fix: jws algorithm param type — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`6b03e93`](https://github.com/OZI-Project/OZI.build/commit/6b03e930347d2f3ea7ea8d4c7f8d681096143b3a))

* fix:  add endpoint  dev-87evx9ru.auth0.com:443 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`9bdaffc`](https://github.com/OZI-Project/OZI.build/commit/9bdaffcbb1eff1a1cb6aaca66834b03c94bde5dc))

* fix: vendored import typo — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`ac5905a`](https://github.com/OZI-Project/OZI.build/commit/ac5905a57a1d6e2a4a41633e33e961a33e361725))

* fix: use asymmetric (RS256) token for wheel signing — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`0e70551`](https://github.com/OZI-Project/OZI.build/commit/0e70551ee04280b61988ad2bcb5658362959d410))


### Build system


* build(deps): bump snowballstemmer from 2.2.0 to 3.0.0.1 in /doc

Bumps [snowballstemmer](https://github.com/snowballstem/snowball) from 2.2.0 to 3.0.0.1.
- [Changelog](https://github.com/snowballstem/snowball/blob/master/NEWS)
- [Commits](https://github.com/snowballstem/snowball/commits)


updated-dependencies:
- dependency-name: snowballstemmer
  dependency-version: 3.0.0.1
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`676bd96`](https://github.com/OZI-Project/OZI.build/commit/676bd9625c4676d1bc5838015c45be575d4f59fa))

* build(deps): bump urllib3 from 2.2.3 to 2.4.0 in /doc

Bumps [urllib3](https://github.com/urllib3/urllib3) from 2.2.3 to 2.4.0.
- [Release notes](https://github.com/urllib3/urllib3/releases)
- [Changelog](https://github.com/urllib3/urllib3/blob/main/CHANGES.rst)
- [Commits](https://github.com/urllib3/urllib3/compare/2.2.3...2.4.0)


updated-dependencies:
- dependency-name: urllib3
  dependency-version: 2.4.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0a29314`](https://github.com/OZI-Project/OZI.build/commit/0a293142f6109a73631c6b2f6308cf2c28595c53))

* build(deps): bump actions/dependency-review-action from 4.6.0 to 4.7.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.6.0 to 4.7.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/ce3cf9537a52e8119d91fd484ab5b8a807627bf8...38ecb5b593bf0eb19e335c03f97670f792489a8b)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-version: 4.7.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1d76e07`](https://github.com/OZI-Project/OZI.build/commit/1d76e07dddf6851a20deb59cde198edb7a1c3287))


### Chores


* chore: run isort — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`9f763ef`](https://github.com/OZI-Project/OZI.build/commit/9f763ef3f47adcf5f7df1673b03fc2926a2eaa98))

## 2.2.0 (2025-05-09)


### Bug fixes


* fix: skip wheel sign if WHEEL_SIGN_TOKEN is unset — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`b3b3f8b`](https://github.com/OZI-Project/OZI.build/commit/b3b3f8b2b903b4d89609da8ab2ed3632987fcae3))


### Chores


* chore: sign-wheel-files enabled — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`257ccab`](https://github.com/OZI-Project/OZI.build/commit/257ccabbcf9d56d9c4713d074c6513a47a17a45e))

## 2.1.1 (2025-05-08)


### Bug fixes


* fix: readme typo — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`dfd937b`](https://github.com/OZI-Project/OZI.build/commit/dfd937be4fc2f7184fcb59e924d6a946bb097432))


### Build system


* build(deps): bump OZI-Project/publish from 1.13.4 to 1.13.5

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.4 to 1.13.5.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/8297bf52054be7cae27ab2770e08d96676fd3162...2db0b4c8cd2073e42b9aa5f399020b78cfee31e0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.5
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3e78144`](https://github.com/OZI-Project/OZI.build/commit/3e78144fc159bbfe2f94e24cdcbf3e357ba3fb71))

* build(deps): bump OZI-Project/draft from 1.13.2 to 1.13.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.2 to 1.13.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/92712f8a95c9cb1fa00731f9a29edeb1cd9799b8...68b9a0082a1e1fafa581b7cb6488254df5f47a39)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`91ffc59`](https://github.com/OZI-Project/OZI.build/commit/91ffc5967bbc5cd1598f8407d88da7cf61b21673))

* build(deps): update ozi-build requirement from ~=2.0 to ~=2.1 in /doc

Updates the requirements on [ozi-build](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/2.0.0...2.1.0)


updated-dependencies:
- dependency-name: ozi-build
  dependency-version: 2.1.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`b04f5ae`](https://github.com/OZI-Project/OZI.build/commit/b04f5ae20a3ffb653941770f7fd91febf8dbb7ae))


### Chores


* chore: update docs for 1.1 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`4464b5e`](https://github.com/OZI-Project/OZI.build/commit/4464b5e582ec85678ab952cce92146e6fb5cc112))

* chore: update documentation for version 2.2 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`25e78ba`](https://github.com/OZI-Project/OZI.build/commit/25e78bab88959e3abcf75a6db1f111fe068e6a89))

## 2.1.0 (2025-05-06)


### Build system


* build(deps): bump charset-normalizer from 3.4.1 to 3.4.2 in /doc

Bumps [charset-normalizer](https://github.com/jawah/charset_normalizer) from 3.4.1 to 3.4.2.
- [Release notes](https://github.com/jawah/charset_normalizer/releases)
- [Changelog](https://github.com/jawah/charset_normalizer/blob/master/CHANGELOG.md)
- [Commits](https://github.com/jawah/charset_normalizer/compare/3.4.1...3.4.2)


updated-dependencies:
- dependency-name: charset-normalizer
  dependency-version: 3.4.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3a7ed9f`](https://github.com/OZI-Project/OZI.build/commit/3a7ed9fcdb64954d4536c1cab225c69427e632dc))

* build(deps): bump github/codeql-action from 3.28.16 to 3.28.17

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.16 to 3.28.17.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/28deaeda66b76a05916b6923827895f2b14ab387...60168efe1c415ce0f5521ea06d5c2062adbeed1b)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.17
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5eaaf41`](https://github.com/OZI-Project/OZI.build/commit/5eaaf4119db16dee36ebb0c8d333d6ef5d5ef5b4))

## 2.0.10 (2025-05-04)


### Build system


* build(deps): bump OZI-Project/draft from 1.13.1 to 1.13.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.1 to 1.13.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/ed08d630ad83cfd14061b78cf695c20eb51984a5...92712f8a95c9cb1fa00731f9a29edeb1cd9799b8)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`586fb2e`](https://github.com/OZI-Project/OZI.build/commit/586fb2ebb5aefb0b6fa6e86bb3180802a6aec5a0))

* build(deps): bump OZI-Project/publish from 1.13.3 to 1.13.4

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.3 to 1.13.4.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/df67e9c0f38d22c078568807d2eefed313340e2d...8297bf52054be7cae27ab2770e08d96676fd3162)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ae0339a`](https://github.com/OZI-Project/OZI.build/commit/ae0339a1ff10299e3681c56475aa003e5d0cd2c5))

* build(deps): bump OZI-Project/checkpoint from 1.7.1 to 1.7.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/dbe6f38e4bb6ed375129d0cf718b6d6968340a13...ac9e45ece7eecacce1a9acb44ae4443985fe310b)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4911358`](https://github.com/OZI-Project/OZI.build/commit/4911358743ef325c733e5583da9b049c8549074e))

## 2.0.9 (2025-05-01)


### Bug fixes


* fix: meson support upper limit of 1.9

perf: clean up build API
([`053b318`](https://github.com/OZI-Project/OZI.build/commit/053b318ab939f3f61110ed52d56f6113ceb795f4))


### Build system


* build(deps): bump certifi from 2025.1.31 to 2025.4.26 in /doc

Bumps [certifi](https://github.com/certifi/python-certifi) from 2025.1.31 to 2025.4.26.
- [Commits](https://github.com/certifi/python-certifi/compare/2025.01.31...2025.04.26)


updated-dependencies:
- dependency-name: certifi
  dependency-version: 2025.4.26
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`fdf6a91`](https://github.com/OZI-Project/OZI.build/commit/fdf6a915ea7782e364b0bf95848d42901e20565a))

## 2.0.8 (2025-04-26)

## 2.0.7 (2025-04-26)


### Build system


* build(deps): bump actions/download-artifact from 4.2.1 to 4.3.0

Bumps [actions/download-artifact](https://github.com/actions/download-artifact) from 4.2.1 to 4.3.0.
- [Release notes](https://github.com/actions/download-artifact/releases)
- [Commits](https://github.com/actions/download-artifact/compare/95815c38cf2ff2164869cbab79da8d1f422bc89e...d3f86a106a0bac45b974a628896c90dbdf5c8093)


updated-dependencies:
- dependency-name: actions/download-artifact
  dependency-version: 4.3.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`ca23bbf`](https://github.com/OZI-Project/OZI.build/commit/ca23bbfcfbad874aa5610487aed002951d9e0e8e))

## 2.0.6 (2025-04-24)

## 2.0.5 (2025-04-24)

## 2.0.4 (2025-04-24)

## 2.0.3 (2025-04-24)


### Build system


* build(deps): bump setuptools-scm[toml] from 8.3.0 to 8.3.1 in /doc

Bumps [setuptools-scm[toml]](https://github.com/pypa/setuptools-scm) from 8.3.0 to 8.3.1.
- [Release notes](https://github.com/pypa/setuptools-scm/releases)
- [Changelog](https://github.com/pypa/setuptools-scm/blob/main/CHANGELOG.md)
- [Commits](https://github.com/pypa/setuptools-scm/compare/v8.3.0...v8.3.1)


updated-dependencies:
- dependency-name: setuptools-scm[toml]
  dependency-version: 8.3.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`827f198`](https://github.com/OZI-Project/OZI.build/commit/827f1986f8cc46d2d41a8f3ad5a738a7678d363c))

* build(deps): bump github/codeql-action from 3.28.15 to 3.28.16

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.15 to 3.28.16.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/45775bd8235c68ba998cffa5171334d58593da47...28deaeda66b76a05916b6923827895f2b14ab387)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.16
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`97e12ca`](https://github.com/OZI-Project/OZI.build/commit/97e12cac5476e008d0f080546821df70778aeac8))

## 2.0.2 (2025-04-23)

## 2.0.1 (2025-04-23)


### Build system


* build(deps): bump setuptools-scm[toml] from 8.2.1 to 8.3.0 in /doc

Bumps [setuptools-scm[toml]](https://github.com/pypa/setuptools-scm) from 8.2.1 to 8.3.0.
- [Release notes](https://github.com/pypa/setuptools-scm/releases)
- [Changelog](https://github.com/pypa/setuptools-scm/blob/main/CHANGELOG.md)
- [Commits](https://github.com/pypa/setuptools-scm/compare/v8.2.1...v8.3.0)


updated-dependencies:
- dependency-name: setuptools-scm[toml]
  dependency-version: 8.3.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1a8b7ab`](https://github.com/OZI-Project/OZI.build/commit/1a8b7ab2925e367b5ab124cf49d65a0203773756))

* build(deps): update ozi-build requirement from ~=1.14 to ~=2.0 in /doc

Updates the requirements on [ozi-build](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/1.14.0...2.0.0)


updated-dependencies:
- dependency-name: ozi-build
  dependency-version: 2.0.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`86547bf`](https://github.com/OZI-Project/OZI.build/commit/86547bfe04c000b071e47b923381cb7d8c51d09d))

## 2.0.0 (2025-04-22)


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.7.0 to 1.7.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.7.0 to 1.7.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/bec3d96cd1cb3bbce358fbeabc70eb25482bd3bf...dbe6f38e4bb6ed375129d0cf718b6d6968340a13)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1c2a73c`](https://github.com/OZI-Project/OZI.build/commit/1c2a73ca62870af263a02682e6183ddc1592fa96))

* build(deps): bump OZI-Project/publish from 1.13.1 to 1.13.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.1 to 1.13.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/26f38aa55610d51537ae92c1e89464a18959ba90...df67e9c0f38d22c078568807d2eefed313340e2d)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.3
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f1e0bb0`](https://github.com/OZI-Project/OZI.build/commit/f1e0bb021ed990742c83c3ce9c9bd4ab0a6c5675))

* build(deps): bump soupsieve from 2.6 to 2.7 in /doc

Bumps [soupsieve](https://github.com/facelessuser/soupsieve) from 2.6 to 2.7.
- [Release notes](https://github.com/facelessuser/soupsieve/releases)
- [Commits](https://github.com/facelessuser/soupsieve/compare/2.6...2.7)


updated-dependencies:
- dependency-name: soupsieve
  dependency-version: '2.7'
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`2aed00a`](https://github.com/OZI-Project/OZI.build/commit/2aed00a5c28647e6a1831292200121b6311433cd))

* build(deps): update ozi-build requirement from ~=1.13 to ~=1.14 in /doc

Updates the requirements on [ozi-build](https://github.com/OZI-Project/OZI.build) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/OZI.build/releases)
- [Changelog](https://github.com/OZI-Project/OZI.build/blob/master/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/OZI.build/compare/1.13.0...1.14.0)


updated-dependencies:
- dependency-name: ozi-build
  dependency-version: 1.14.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`1bd825f`](https://github.com/OZI-Project/OZI.build/commit/1bd825f1bcc02640456a6da8166eb670796b537c))

* build(deps): bump packaging from 24.2 to 25.0 in /doc

Bumps [packaging](https://github.com/pypa/packaging) from 24.2 to 25.0.
- [Release notes](https://github.com/pypa/packaging/releases)
- [Changelog](https://github.com/pypa/packaging/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pypa/packaging/compare/24.2...25.0)


updated-dependencies:
- dependency-name: packaging
  dependency-version: '25.0'
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`6d33cc9`](https://github.com/OZI-Project/OZI.build/commit/6d33cc96c212e2a80b638c474eeac1400f4c4a90))

* build(deps): bump step-security/harden-runner from 2.11.1 to 2.12.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.11.1 to 2.12.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/c6295a65d1254861815972266d5933fd6e532bdf...0634a2670c59f64b4a01f0f96f84700a4088b9f0)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-version: 2.12.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c27a807`](https://github.com/OZI-Project/OZI.build/commit/c27a8078bbb56b714906b902b274b77514881fb6))


### Unknown


* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`77a0244`](https://github.com/OZI-Project/OZI.build/commit/77a0244f975b963ca95ce91907e86bb2315cfae5))

## 1.14.0 (2025-04-19)


### Bug fixes


* fix: maybe_add_key_to_project doesnt duplicate keys — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`74b14a8`](https://github.com/OZI-Project/OZI.build/commit/74b14a87198c597ec44a9090d9c4974e3f1f2fce))

* fix: sre_parse module name typo — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`be54fc3`](https://github.com/OZI-Project/OZI.build/commit/be54fc3db4e769dc4d06fb417bc20802eeafe265))

* fix: re internals version guard — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`63f7e00`](https://github.com/OZI-Project/OZI.build/commit/63f7e008920a2419eb3279b8ebb762f83e00c53f))

* fix: handle re internals correctly in <3.11 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`efef6e5`](https://github.com/OZI-Project/OZI.build/commit/efef6e5d59b7ad1170860589e6b4d96bb82e1193))

* fix: force meson install to tox envs — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`d72c859`](https://github.com/OZI-Project/OZI.build/commit/d72c859978d604515f5a315dad2f7371716a5d13))

* fix: remove distutils import — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`442f30a`](https://github.com/OZI-Project/OZI.build/commit/442f30af80a00569174af056b71bcefa9e8a5b38))

* fix: _sre import of re internals — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`a442079`](https://github.com/OZI-Project/OZI.build/commit/a442079cef750dce7f2db9e9158ced1612ebeb7e))

* fix: get_requires_for_build_wheel/sdist no longer returns an empty list in all cases — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`aba9877`](https://github.com/OZI-Project/OZI.build/commit/aba987776be6d054ba8292e37421366bb510a8f9))

* fix: filter empty config args — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`6c5171c`](https://github.com/OZI-Project/OZI.build/commit/6c5171ca75c9ab51d34839cd5359ab3f6af1598c))

* fix: use search instead of match — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`91db7a2`](https://github.com/OZI-Project/OZI.build/commit/91db7a2dac0fcd644a0cae00a87dc4aba75e985e))

* fix: return basename from build_wheel — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`1d495e5`](https://github.com/OZI-Project/OZI.build/commit/1d495e512c5729186ef9e45fac3eb5072cae4231))

* fix: license-file guard without indexing — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`72ed911`](https://github.com/OZI-Project/OZI.build/commit/72ed9119823cd5c64b2bb7f34b34f2a26a1f36a8))

* fix: remove legacy license table parsing — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`f585924`](https://github.com/OZI-Project/OZI.build/commit/f58592487fa837fcc0d51ea2d4984e474799b30f))

* fix: correct dict get — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`7ba9665`](https://github.com/OZI-Project/OZI.build/commit/7ba96650f09b82087a290d3d41da4c132f9845d2))

* fix: make the tool table optional — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`b100a83`](https://github.com/OZI-Project/OZI.build/commit/b100a833a13019ce768d7913e3ab6f65915a0934))

* fix: tool.ozi-build should not be a required table — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`11b2009`](https://github.com/OZI-Project/OZI.build/commit/11b20096231871616d46ff398a6574c4bb915b4e))

* fix: correctly parse authors and maintainers — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`0fa0356`](https://github.com/OZI-Project/OZI.build/commit/0fa035627fe778803e468cbcc3b7a48e0e7a81a4))

* fix: entry_points.txt values unquoted — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`11e0ef6`](https://github.com/OZI-Project/OZI.build/commit/11e0ef6579aa3199f9f73bdaf7391214432be30c))

* fix: clarify meson-python-option-name warning — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`ea68b41`](https://github.com/OZI-Project/OZI.build/commit/ea68b41a6700d53a3e7cfd47f59c2822ccb9af1c))

* fix: cleanup pyc_wheel outputs — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`cf2d9f0`](https://github.com/OZI-Project/OZI.build/commit/cf2d9f0e1a186c613ae714bcfe55104763a6fcd9))

* fix: properly handle required metadata name/version

BREAKING CHANGE: Major change to how metadata is handled — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`fce28dc`](https://github.com/OZI-Project/OZI.build/commit/fce28dc65a1beb73ead2fc12b0019a4335fb6253))

* fix: remove f-strings for compatibility — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`c8b0672`](https://github.com/OZI-Project/OZI.build/commit/c8b0672c27f291f868eae32a811248578f606cec))


### Build system


* build(deps): bump beautifulsoup4 from 4.13.3 to 4.13.4 in /doc

Bumps [beautifulsoup4](https://www.crummy.com/software/BeautifulSoup/bs4/) from 4.13.3 to 4.13.4.


updated-dependencies:
- dependency-name: beautifulsoup4
  dependency-version: 4.13.4
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`795e617`](https://github.com/OZI-Project/OZI.build/commit/795e61745231eb55657a4bbdd135cfb7ef1bd181))

* build(deps): bump prompt-toolkit from 3.0.50 to 3.0.51 in /doc

Bumps [prompt-toolkit](https://github.com/prompt-toolkit/python-prompt-toolkit) from 3.0.50 to 3.0.51.
- [Release notes](https://github.com/prompt-toolkit/python-prompt-toolkit/releases)
- [Changelog](https://github.com/prompt-toolkit/python-prompt-toolkit/blob/main/CHANGELOG)
- [Commits](https://github.com/prompt-toolkit/python-prompt-toolkit/compare/3.0.50...3.0.51)


updated-dependencies:
- dependency-name: prompt-toolkit
  dependency-version: 3.0.51
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`39c104c`](https://github.com/OZI-Project/OZI.build/commit/39c104c29b6aba86b6727dcd14d5c4c232e0a431))

* build: add Provides-Dist: pyc_wheel — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`b1dcb4e`](https://github.com/OZI-Project/OZI.build/commit/b1dcb4e78d4c85e15e5146c2fc517a66df4a12dd))


### Chores


* chore: update readme with PyJWT license info — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`a73b6f2`](https://github.com/OZI-Project/OZI.build/commit/a73b6f2ba0cedb89e94ed317fc4b95aea83be109))

* chore: exclude vendored PyJWT from flake8 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`c5b0e17`](https://github.com/OZI-Project/OZI.build/commit/c5b0e172c278c8da9e80fcdcd0e06476f3d66a49))

* chore: cleanup lint — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`da6f310`](https://github.com/OZI-Project/OZI.build/commit/da6f310f5c2e2b8a566aa6d8db966d13df191cde))

* chore: clean up API — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`7791886`](https://github.com/OZI-Project/OZI.build/commit/7791886d9381988a6306f0761c46bcd9f824906a))

* chore: remove dep install dist scripts — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`7afc48d`](https://github.com/OZI-Project/OZI.build/commit/7afc48dacc43915f0b95eb64952bd5d6a99b3703))

* chore: update wrap-file to OZI-1.41.5 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`cc4eb20`](https://github.com/OZI-Project/OZI.build/commit/cc4eb20e23fcd73f4e2f379eac231b1821c914c3))

* chore: move metadata related constants to metadata module — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`da133ed`](https://github.com/OZI-Project/OZI.build/commit/da133ed29868c59c406efb1669ce38d45a1955de))

* chore: run black — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`0d8fe8d`](https://github.com/OZI-Project/OZI.build/commit/0d8fe8d4ad08f46a9873465ee49cc081227243fc))

* chore: update documentation for 2.0 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`4c0dd3d`](https://github.com/OZI-Project/OZI.build/commit/4c0dd3d3163abd3b44591583f13869972163bdcc))

* chore: clean up deprecated imports — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`99fc1c3`](https://github.com/OZI-Project/OZI.build/commit/99fc1c309da84a0b6a9ee4ee1b84faeaec9f5927))

* chore: update config option validation — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`a317d86`](https://github.com/OZI-Project/OZI.build/commit/a317d86aaf244a0b987a4b40408ff5c81a2db080))

* chore: update project metadata — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`8e50463`](https://github.com/OZI-Project/OZI.build/commit/8e504631a42421afb81876c7ac15345a8e4a8bde))

* chore: remove deprecated download-url — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`2ae9711`](https://github.com/OZI-Project/OZI.build/commit/2ae9711272b1e20fb497192103398f7fcf6c8d0d))


### Features


* feat: add jws RECORD signing and ``sign-wheel-files`` config setting — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`4e1e97c`](https://github.com/OZI-Project/OZI.build/commit/4e1e97c79291644bfae6f0fa1fabac110b9847b7))

* feat: vendor PyJWT 2.10.1 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`c86e710`](https://github.com/OZI-Project/OZI.build/commit/c86e7107305cc9915617bd3b66adab31d6ab0450))

* feat: Wheel-Version 1.9 include Generator version — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`8ff9826`](https://github.com/OZI-Project/OZI.build/commit/8ff98262e019e22ce599b17f37a309b474343edf))

* feat: deprecate [tool.ozi-build.metadata] — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`c9acb3e`](https://github.com/OZI-Project/OZI.build/commit/c9acb3e2d4f021f347d6d555b8ed48fa3a603588))

* feat: rewrite pyproject.toml to include name and version during sdist — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`5e8acf7`](https://github.com/OZI-Project/OZI.build/commit/5e8acf7e53654b0ee2fce324afb8934d413fc924))


### Performance improvements


* perf: warn if ``sign-wheel-files`` is true but ``WHEEL_SIGN_TOKEN`` env var isn't set — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`610cf8b`](https://github.com/OZI-Project/OZI.build/commit/610cf8b289efa3af8ea9959c70394fe845b75759))

* perf: add several known reDOS pattern tests labelled by ``test_cve_...`` — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`185537c`](https://github.com/OZI-Project/OZI.build/commit/185537cb84e31b5eb90a9a325cb24a1a071e1941))

* perf: copy regexploit tests to repo — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`828fb2d`](https://github.com/OZI-Project/OZI.build/commit/828fb2d0cf625ae734848e7f6ecd1999f5e35327))

* perf: use uv for OZI backend — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`4e2180f`](https://github.com/OZI-Project/OZI.build/commit/4e2180f931ff968235d4d11c75a9255093914276))

* perf: move regexploit entrypoint to new _regexploit module — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`fbfc5c6`](https://github.com/OZI-Project/OZI.build/commit/fbfc5c6ab4f114eaf8f0633b371fa5e2a16c6e29))

* perf: patch pyproject for OZI 1.39 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`ee362ef`](https://github.com/OZI-Project/OZI.build/commit/ee362eff99cc039145a20dc153e160704f48c282))

* perf: patch pyproject for OZI 1.39 — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`dbb85eb`](https://github.com/OZI-Project/OZI.build/commit/dbb85eb57cfff2018ee7f76ea0da2c58ecedb9a4))

* perf: clean up build API — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`4bf1070`](https://github.com/OZI-Project/OZI.build/commit/4bf107079faf5f6eccc7e6d45e69cfc48db06dd1))

* perf: replace version during sdist — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`bd72361`](https://github.com/OZI-Project/OZI.build/commit/bd72361b37160781ca8180d955b3fcc343ac38d2))

* perf: replace version during sdist — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`82d016b`](https://github.com/OZI-Project/OZI.build/commit/82d016bc347b0978770fcfe7c6d0e8cd36bc4f82))

* perf: split ``pip`` extra from ``core`` extra — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`185bd6c`](https://github.com/OZI-Project/OZI.build/commit/185bd6c3996ebe04b56b460be027ac2e62f2e53f))

* perf: deprecate pre-prepared PKG-INFO from setuptools_scm

BREAKING_CHANGE: This fully removes ``check_pkg_info_file``. — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`0f823ce`](https://github.com/OZI-Project/OZI.build/commit/0f823ce9cd1209f0a397edf922f547291da3ece2))

* perf: warn about deprecated metadata — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`6a67ed9`](https://github.com/OZI-Project/OZI.build/commit/6a67ed91c565b3bd68670dec0d2e3c66e865ea96))

* perf: redos checker output now NO_COLOR friendly — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`0c17a5b`](https://github.com/OZI-Project/OZI.build/commit/0c17a5bcde73e91d21a4eb9ce469f541c7b300ff))

* perf: add warning that name and version will be overwritten by sdist — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`1fdce1b`](https://github.com/OZI-Project/OZI.build/commit/1fdce1b25c2ae8ef22c041decdebe8f65388c3af))

## 1.13.3 (2025-04-16)


### Build system


* build: Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c8b5be1`](https://github.com/OZI-Project/OZI.build/commit/c8b5be19364d40e8327564f067c812755be2027c))

## 1.13.2 (2025-04-16)


### Build system


* build: delete .python-version — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`73f3740`](https://github.com/OZI-Project/OZI.build/commit/73f37407745c7b8fa819b7d54ee7e7418271138c))

* build: Update ozi.yml to always create a merge PR — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`578aa45`](https://github.com/OZI-Project/OZI.build/commit/578aa456a4df2edc1173629221578aa92d28d62d))

## 1.13.1 (2025-04-08)

## 1.13.0 (2025-04-02)


### Bug fixes


* fix: normalize PKG-INFO dir
([`667d7c7`](https://github.com/OZI-Project/OZI.build/commit/667d7c7f00f17a7e5d493d28e363d6c99bddb6a3))

* fix: normalize PKG-INFO dir
([`0f34d40`](https://github.com/OZI-Project/OZI.build/commit/0f34d4067138823eed0bae3e6c02d13c1a7818f5))

* fix: correct name normalization — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`2ba634b`](https://github.com/OZI-Project/OZI.build/commit/2ba634bf518023161006d2dd9ed70d61143cc0ca))

* fix: correct name normalization — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`d17df08`](https://github.com/OZI-Project/OZI.build/commit/d17df0876cef25f5952d43df3bb318e2367a8fed))

* fix: normalize package name in dist files — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`aa7f356`](https://github.com/OZI-Project/OZI.build/commit/aa7f3569bc2f1e64cd833754a5b5274cffb500ba))


### Build system


* build(deps): bump wheel from 0.45.1 to 0.46.1 in /doc

Bumps [wheel](https://github.com/pypa/wheel) from 0.45.1 to 0.46.1.
- [Release notes](https://github.com/pypa/wheel/releases)
- [Changelog](https://github.com/pypa/wheel/blob/main/docs/news.rst)
- [Commits](https://github.com/pypa/wheel/compare/0.45.1...0.46.1)


updated-dependencies:
- dependency-name: wheel
  dependency-version: 0.46.1
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`d3d95aa`](https://github.com/OZI-Project/OZI.build/commit/d3d95aad2ec2712044e2904f576de5717be5981a))

* build(deps): bump OZI-Project/publish from 1.13.0 to 1.13.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.13.0 to 1.13.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/dedb3175dc5d4bb29bcee5a7b659ad7f42c5c68c...26f38aa55610d51537ae92c1e89464a18959ba90)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-version: 1.13.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a438a5a`](https://github.com/OZI-Project/OZI.build/commit/a438a5ac8e7d2f5dad2c2b7c6c655a642d22fdbd))

* build(deps): bump OZI-Project/draft from 1.13.0 to 1.13.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.13.0 to 1.13.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/917b6a5d9a39df52cbdc3a15565c58dfb9b38a10...ed08d630ad83cfd14061b78cf695c20eb51984a5)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-version: 1.13.1
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1c20169`](https://github.com/OZI-Project/OZI.build/commit/1c20169531c31e15aa6a124991ec37acbe46cf06))

* build(deps): bump OZI-Project/checkpoint from 1.6.0 to 1.7.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.6.0 to 1.7.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/175eae79f299d6dbad474024b5f791368bd5de85...bec3d96cd1cb3bbce358fbeabc70eb25482bd3bf)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-version: 1.7.0
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`ceb9ee2`](https://github.com/OZI-Project/OZI.build/commit/ceb9ee2cae10f39c0c066e12d0120cff30d53002))

* build(deps): bump meson[ninja] from 1.7.1 to 1.7.2 in /doc

Bumps [meson[ninja]](https://github.com/mesonbuild/meson) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/mesonbuild/meson/releases)
- [Commits](https://github.com/mesonbuild/meson/compare/1.7.1...1.7.2)


updated-dependencies:
- dependency-name: meson[ninja]
  dependency-version: 1.7.2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d69bd61`](https://github.com/OZI-Project/OZI.build/commit/d69bd6108260e0e0bfa9f6cbcce0327b3f1907b8))

* build(deps): update ozi-build requirement from ~=1.12 to ~=1.13 in /doc


updated-dependencies:
- dependency-name: ozi-build
  dependency-version: 1.13.0
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`f1d4511`](https://github.com/OZI-Project/OZI.build/commit/f1d45116dae8206b0b012d8ad0a8cde9f350d7ca))

* build(deps): bump github/codeql-action from 3.28.13 to 3.28.15

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.13 to 3.28.15.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/1b549b9259bda1cb5ddde3b41741a82a2d15a841...45775bd8235c68ba998cffa5171334d58593da47)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-version: 3.28.15
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d9cda30`](https://github.com/OZI-Project/OZI.build/commit/d9cda30481d71927b1ea51329cd494b77383e1a1))

* build(deps): bump meson[ninja] from 1.7.0 to 1.7.1 in /doc

Bumps [meson[ninja]](https://github.com/mesonbuild/meson) from 1.7.0 to 1.7.1.
- [Release notes](https://github.com/mesonbuild/meson/releases)
- [Commits](https://github.com/mesonbuild/meson/compare/1.7.0...1.7.1)


updated-dependencies:
- dependency-name: meson[ninja]
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1fa846a`](https://github.com/OZI-Project/OZI.build/commit/1fa846a43a81f6487a5c4fe0fbdd8ddb21cee4e7))

* build(deps): bump step-security/harden-runner from 2.11.0 to 2.11.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.11.0 to 2.11.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/4d991eb9b905ef189e4c376166672c3f2f230481...c6295a65d1254861815972266d5933fd6e532bdf)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`53c6134`](https://github.com/OZI-Project/OZI.build/commit/53c61345d6689efedd1e96e538ceef8e71a7e615))

* build(deps): bump actions/dependency-review-action from 4.5.0 to 4.6.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.5.0 to 4.6.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/3b139cfc5fae8b618d3eae3675e383bb1769c019...ce3cf9537a52e8119d91fd484ab5b8a807627bf8)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0157215`](https://github.com/OZI-Project/OZI.build/commit/0157215c6b94ee0069e427ac278725ac822dc7d4))

* build: remove OZI.build from deps — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`0d63bc2`](https://github.com/OZI-Project/OZI.build/commit/0d63bc289dd84f0263541ee63fac880e777b3923))

* build(deps): bump actions/download-artifact from 4.1.8 to 4.2.1

Bumps [actions/download-artifact](https://github.com/actions/download-artifact) from 4.1.8 to 4.2.1.
- [Release notes](https://github.com/actions/download-artifact/releases)
- [Commits](https://github.com/actions/download-artifact/compare/fa0a91b85d4f404e444e00e005971372dc801d16...95815c38cf2ff2164869cbab79da8d1f422bc89e)


updated-dependencies:
- dependency-name: actions/download-artifact
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`9c1507e`](https://github.com/OZI-Project/OZI.build/commit/9c1507e34b52b66c341a1021ab2ad4b226f9e8ac))

* build(deps): bump OZI-Project/checkpoint from 1.5.5 to 1.6.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.5 to 1.6.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/f14cac563125e34d106b3a1e0ddb2773062953e5...175eae79f299d6dbad474024b5f791368bd5de85)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`eb9c773`](https://github.com/OZI-Project/OZI.build/commit/eb9c773cd2884f694f08f36f19ed1e67bc393657))

* build(deps): bump pyparsing from 3.2.2 to 3.2.3 in /doc

Bumps [pyparsing](https://github.com/pyparsing/pyparsing) from 3.2.2 to 3.2.3.
- [Release notes](https://github.com/pyparsing/pyparsing/releases)
- [Changelog](https://github.com/pyparsing/pyparsing/blob/master/CHANGES)
- [Commits](https://github.com/pyparsing/pyparsing/compare/3.2.2...3.2.3)


updated-dependencies:
- dependency-name: pyparsing
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7409ec1`](https://github.com/OZI-Project/OZI.build/commit/7409ec10439724df59ab22b647937efc6c7f615a))

* build(deps): bump OZI-Project/publish from 1.10.1 to 1.13.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.10.1 to 1.13.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/9d10868569d8cf25647f221a223d27cfe545ffb2...dedb3175dc5d4bb29bcee5a7b659ad7f42c5c68c)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`fb00641`](https://github.com/OZI-Project/OZI.build/commit/fb00641c77add0b82383dfb8b03d31310db1fced))

* build(deps): bump OZI-Project/draft from 1.11.1 to 1.13.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.11.1 to 1.13.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/d593fa1d1df726466bd156d239ed36986d1c2ab9...917b6a5d9a39df52cbdc3a15565c58dfb9b38a10)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`9bf47c4`](https://github.com/OZI-Project/OZI.build/commit/9bf47c4351cabbf28d63b926a07500881b00769f))

* build(deps): bump actions/upload-artifact from 4.6.0 to 4.6.2

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.6.0 to 4.6.2.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/65c4c4a1ddee5b72f698fdd19549f0f0fb45cf08...ea165f8d65b6e75b540449e92b4886f43607fa02)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ffb8785`](https://github.com/OZI-Project/OZI.build/commit/ffb8785069226dc7775340aafbe5a53162f846bd))

* build(deps): bump ossf/scorecard-action from 2.4.0 to 2.4.1

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.4.0 to 2.4.1.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/62b2cac7ed8198b15735ed49ab1e5cf35480ba46...f49aabe0b5af0936a0987cfb85d86b75731b0186)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c80890b`](https://github.com/OZI-Project/OZI.build/commit/c80890b7df665dfc87e265e6caabd3ba8770ac1c))

* build(deps): bump github/codeql-action from 3.28.9 to 3.28.13

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.9 to 3.28.13.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/9e8d0789d4a0fa9ceb6b1738f7e269594bdd67f0...1b549b9259bda1cb5ddde3b41741a82a2d15a841)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`571dd82`](https://github.com/OZI-Project/OZI.build/commit/571dd826066fdb4f6156ef168a6a516cd5d84480))

* build(deps): update ozi-build requirement from ~=1.11 to ~=1.12 in /doc


updated-dependencies:
- dependency-name: ozi-build
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`40a30c0`](https://github.com/OZI-Project/OZI.build/commit/40a30c05a8cad487fbf5359ea8b5c4df643611d1))

* build(deps): bump stevedore from 5.4.0 to 5.4.1 in /doc

Bumps [stevedore](https://docs.openstack.org/stevedore/latest/) from 5.4.0 to 5.4.1.


updated-dependencies:
- dependency-name: stevedore
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e551a4f`](https://github.com/OZI-Project/OZI.build/commit/e551a4ffeb79023968c24340fdc5c8ec624e676d))

* build(deps): bump setuptools-scm[toml] from 8.1.0 to 8.2.1 in /doc

Bumps [setuptools-scm[toml]](https://github.com/pypa/setuptools-scm) from 8.1.0 to 8.2.1.
- [Release notes](https://github.com/pypa/setuptools-scm/releases)
- [Changelog](https://github.com/pypa/setuptools-scm/blob/main/CHANGELOG.md)
- [Commits](https://github.com/pypa/setuptools-scm/compare/v8.1.0...v8.2.1)


updated-dependencies:
- dependency-name: setuptools-scm[toml]
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f52f832`](https://github.com/OZI-Project/OZI.build/commit/f52f8325c47193c1e720140a373753ccbb9e983f))

* build(deps): bump pyparsing from 3.2.1 to 3.2.2 in /doc

Bumps [pyparsing](https://github.com/pyparsing/pyparsing) from 3.2.1 to 3.2.2.
- [Release notes](https://github.com/pyparsing/pyparsing/releases)
- [Changelog](https://github.com/pyparsing/pyparsing/blob/master/CHANGES)
- [Commits](https://github.com/pyparsing/pyparsing/compare/3.2.1...3.2.2)


updated-dependencies:
- dependency-name: pyparsing
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`705cb74`](https://github.com/OZI-Project/OZI.build/commit/705cb74bb1dd33f360268a5a36cadaeae4796dc9))

* build(deps): bump ninja from 1.11.1.3 to 1.11.1.4 in /doc

Bumps [ninja](https://github.com/scikit-build/ninja-python-distributions) from 1.11.1.3 to 1.11.1.4.
- [Release notes](https://github.com/scikit-build/ninja-python-distributions/releases)
- [Changelog](https://github.com/scikit-build/ninja-python-distributions/blob/master/HISTORY.rst)
- [Commits](https://github.com/scikit-build/ninja-python-distributions/compare/1.11.1.3...1.11.1.4)


updated-dependencies:
- dependency-name: ninja
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b53681f`](https://github.com/OZI-Project/OZI.build/commit/b53681fcf6d1b8d24dfe773d18f569e1472e7ca4))

* build(deps): bump jinja2 from 3.1.5 to 3.1.6 in /doc

Bumps [jinja2](https://github.com/pallets/jinja) from 3.1.5 to 3.1.6.
- [Release notes](https://github.com/pallets/jinja/releases)
- [Changelog](https://github.com/pallets/jinja/blob/main/CHANGES.rst)
- [Commits](https://github.com/pallets/jinja/compare/3.1.5...3.1.6)


updated-dependencies:
- dependency-name: jinja2
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fe8f5fc`](https://github.com/OZI-Project/OZI.build/commit/fe8f5fc76a2690b6ec29c9763c1b593958598a7a))


### Chores


* chore: run black — Eden Ross Duff MSc <rjdbcm@outlook.com>
([`1838fd1`](https://github.com/OZI-Project/OZI.build/commit/1838fd141c1a934495d5f6649a3d4a0106280e03))

* chore: update brand submodule
([`91f2c10`](https://github.com/OZI-Project/OZI.build/commit/91f2c10004fe5777642ef5ee6af3d9fc1edb898c))


### Features


* feat: normalize dist file names

This requires a change in ozi-templates and a patch for every distribution.
([`7108404`](https://github.com/OZI-Project/OZI.build/commit/7108404d3b4de76e8d55b77baf248b45ae5f78c5))


### Unknown


* Create .python-version — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`88a7e1f`](https://github.com/OZI-Project/OZI.build/commit/88a7e1f657999c655483594aed3ca2003d075dca))

## 1.12.0 (2025-02-18)

## 1.11.0 (2025-02-01)


### Build system


* build(deps): update ozi-build requirement from ~=1.10 to ~=1.11 in /doc


updated-dependencies:
- dependency-name: ozi-build
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`9bc5a7f`](https://github.com/OZI-Project/OZI.build/commit/9bc5a7f492239a4697d86880f985ab773b3a0c48))

* build(deps): bump babel from 2.16.0 to 2.17.0 in /doc

Bumps [babel](https://github.com/python-babel/babel) from 2.16.0 to 2.17.0.
- [Release notes](https://github.com/python-babel/babel/releases)
- [Changelog](https://github.com/python-babel/babel/blob/master/CHANGES.rst)
- [Commits](https://github.com/python-babel/babel/compare/v2.16.0...v2.17.0)


updated-dependencies:
- dependency-name: babel
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e06110c`](https://github.com/OZI-Project/OZI.build/commit/e06110c4b5490d9d670ca859a9ec30363280eeeb))

* build(deps): bump pbr from 6.1.0 to 6.1.1 in /doc

Bumps [pbr](https://docs.openstack.org/pbr/latest/) from 6.1.0 to 6.1.1.


updated-dependencies:
- dependency-name: pbr
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`81554db`](https://github.com/OZI-Project/OZI.build/commit/81554db9580d691c7dd82838a90ae79f3b655566))

* build(deps): bump beautifulsoup4 from 4.12.3 to 4.13.3 in /doc

Bumps [beautifulsoup4](https://www.crummy.com/software/BeautifulSoup/bs4/) from 4.12.3 to 4.13.3.


updated-dependencies:
- dependency-name: beautifulsoup4
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`2f9b418`](https://github.com/OZI-Project/OZI.build/commit/2f9b418b88657a1f54fb41e4729b1144ecddf31b))

* build(deps): bump github/codeql-action from 3.28.8 to 3.28.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.8 to 3.28.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/dd746615b3b9d728a6a37ca2045b68ca76d4841a...9e8d0789d4a0fa9ceb6b1738f7e269594bdd67f0)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7870a59`](https://github.com/OZI-Project/OZI.build/commit/7870a59127958bafce9ef3349a4f1a43f8ba5444))

* build(deps): bump OZI-Project/publish from 1.9.3 to 1.10.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.9.3 to 1.10.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/c35059a13b64575387092e163fa91c2a9f5019da...9d10868569d8cf25647f221a223d27cfe545ffb2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`299d475`](https://github.com/OZI-Project/OZI.build/commit/299d4750792703ee013162bb946df572e6a24bcf))

* build(deps): bump OZI-Project/draft from 1.10.1 to 1.11.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.10.1 to 1.11.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/d3c4167df5ea92adf74006a4406ae85bbf8926e5...d593fa1d1df726466bd156d239ed36986d1c2ab9)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`52974a9`](https://github.com/OZI-Project/OZI.build/commit/52974a95b7cd5f6a1787fa9d857ac0b1d8037255))

* build(deps): bump step-security/harden-runner from 2.10.4 to 2.11.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.4 to 2.11.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/cb605e52c26070c328afc4562f0b4ada7618a84e...4d991eb9b905ef189e4c376166672c3f2f230481)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`cabc05f`](https://github.com/OZI-Project/OZI.build/commit/cabc05fc652b1e60721ba79978eddd6336715bf7))


### Features


* feat: deprecate ``home-page`` and ``download-url`` keys — rjdbcm <rjdbcm@outlook.com>
([`a40f222`](https://github.com/OZI-Project/OZI.build/commit/a40f2226945a0dd7b2247b8445ab31304f31bf8b))


### Unknown


* lint: add noqa — rjdbcm <rjdbcm@outlook.com>
([`be7fe27`](https://github.com/OZI-Project/OZI.build/commit/be7fe27dd628387162d6b7b7f6f6a9e252684072))

* lint: run black 2025 stable style — rjdbcm <rjdbcm@outlook.com>
([`4b0a73d`](https://github.com/OZI-Project/OZI.build/commit/4b0a73d9761498a02d29f07578893b2adb8fc2f1))

## 1.10.7 (2025-01-27)

## 1.10.6 (2025-01-26)


### Bug fixes


* fix: correct re.match — rjdbcm <rjdbcm@outlook.com>
([`a41400e`](https://github.com/OZI-Project/OZI.build/commit/a41400e0bb0e30dc19fc67d8201b2414c702dc00))

* fix: use re.search instead of match — rjdbcm <rjdbcm@outlook.com>
([`57097cb`](https://github.com/OZI-Project/OZI.build/commit/57097cb0900ed612fcc82c0a8aa2d7f913e21863))

* fix: run black — rjdbcm <rjdbcm@outlook.com>
([`32d66ad`](https://github.com/OZI-Project/OZI.build/commit/32d66ad111b9974f16f2c88683f4433cc1ebd9be))

* fix: metadata 2.2 is now respected for twine compatibility — rjdbcm <rjdbcm@outlook.com>
([`be1f28d`](https://github.com/OZI-Project/OZI.build/commit/be1f28d1addd8b55febbb37e13e1b6be4c4946a9))


### Build system


* build(deps): bump OZI-Project/draft from 1.9.0 to 1.10.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.9.0 to 1.10.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/31451b7f6a49b6ef70270b59ff70585d76677012...d3c4167df5ea92adf74006a4406ae85bbf8926e5)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c047a3e`](https://github.com/OZI-Project/OZI.build/commit/c047a3ee688bf7e64069266f58a2a7abcfb7d9e6))

* build(deps): bump OZI-Project/checkpoint from 1.5.4 to 1.5.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.4 to 1.5.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/84a85f725520d5661ed417915ccb0e769973879c...f14cac563125e34d106b3a1e0ddb2773062953e5)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b9fc845`](https://github.com/OZI-Project/OZI.build/commit/b9fc845243e5550256a7db5ee82634a719d55eea))

* build(deps): bump certifi from 2024.12.14 to 2025.1.31 in /doc

Bumps [certifi](https://github.com/certifi/python-certifi) from 2024.12.14 to 2025.1.31.
- [Commits](https://github.com/certifi/python-certifi/compare/2024.12.14...2025.01.31)


updated-dependencies:
- dependency-name: certifi
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`e90b858`](https://github.com/OZI-Project/OZI.build/commit/e90b858fb987db8209c9775f7cb93f638311ab3c))

* build(deps): bump OZI-Project/publish from 1.8.0 to 1.9.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.8.0 to 1.9.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/025b6cb35f983387bb0981661eae0beddb8282fe...c35059a13b64575387092e163fa91c2a9f5019da)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0b37286`](https://github.com/OZI-Project/OZI.build/commit/0b372865efb2d8a50c285aa633f5811071d269d0))

* build(deps): bump github/codeql-action from 3.28.5 to 3.28.8

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.5 to 3.28.8.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f6091c0113d1dcf9b98e269ee48e8a7e51b7bdd4...dd746615b3b9d728a6a37ca2045b68ca76d4841a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`526af28`](https://github.com/OZI-Project/OZI.build/commit/526af28367ff49b4fd9848e50fd41708855007b8))

* build(deps): bump step-security/harden-runner from 2.10.3 to 2.10.4

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.3 to 2.10.4.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/v2.10.3...cb605e52c26070c328afc4562f0b4ada7618a84e)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ad856ed`](https://github.com/OZI-Project/OZI.build/commit/ad856edfbaa63d5e8c33ee99ab8facc1bfa0d5d7))

* build(deps): bump meson[ninja] from 1.6.1 to 1.7.0 in /doc

Bumps [meson[ninja]](https://github.com/mesonbuild/meson) from 1.6.1 to 1.7.0.
- [Release notes](https://github.com/mesonbuild/meson/releases)
- [Commits](https://github.com/mesonbuild/meson/compare/1.6.1...1.7.0)


updated-dependencies:
- dependency-name: meson[ninja]
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4f6d1bb`](https://github.com/OZI-Project/OZI.build/commit/4f6d1bb1a8b94faab22456fbe5915cdea3fad4c4))

* build(deps): bump github/codeql-action from 3.28.4 to 3.28.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.4 to 3.28.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ee117c905ab18f32fa0f66c2fe40ecc8013f3e04...f6091c0113d1dcf9b98e269ee48e8a7e51b7bdd4)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4480b9f`](https://github.com/OZI-Project/OZI.build/commit/4480b9fc55bf475728626f1fb05cd58f1403a53a))

* build(deps): bump pypa/gh-action-pypi-publish from 1.12.3 to 1.12.4

Bumps [pypa/gh-action-pypi-publish](https://github.com/pypa/gh-action-pypi-publish) from 1.12.3 to 1.12.4.
- [Release notes](https://github.com/pypa/gh-action-pypi-publish/releases)
- [Commits](https://github.com/pypa/gh-action-pypi-publish/compare/67339c736fd9354cd4f8cb0b744f2b82a74b5c70...76f52bc884231f62b9a034ebfe128415bbaabdfc)


updated-dependencies:
- dependency-name: pypa/gh-action-pypi-publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b5bca9e`](https://github.com/OZI-Project/OZI.build/commit/b5bca9ef578f6f69a28f327cbb5e50ea42d1eee1))

* build(deps): bump prompt-toolkit from 3.0.48 to 3.0.50 in /doc

Bumps [prompt-toolkit](https://github.com/prompt-toolkit/python-prompt-toolkit) from 3.0.48 to 3.0.50.
- [Release notes](https://github.com/prompt-toolkit/python-prompt-toolkit/releases)
- [Changelog](https://github.com/prompt-toolkit/python-prompt-toolkit/blob/master/CHANGELOG)
- [Commits](https://github.com/prompt-toolkit/python-prompt-toolkit/commits)


updated-dependencies:
- dependency-name: prompt-toolkit
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`55f017f`](https://github.com/OZI-Project/OZI.build/commit/55f017fa952de62485ce0c2a128508a90dfa2a1c))

* build(deps): bump github/codeql-action from 3.28.1 to 3.28.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.1 to 3.28.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/b6a472f63d85b9c78a3ac5e89422239fc15e9b3c...ee117c905ab18f32fa0f66c2fe40ecc8013f3e04)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2c37fcf`](https://github.com/OZI-Project/OZI.build/commit/2c37fcf93abebccac341c7436137addf0bd01587))


### Features


* feat: Core Metadata 2.3 — rjdbcm <rjdbcm@outlook.com>
([`31dc042`](https://github.com/OZI-Project/OZI.build/commit/31dc042921f079f96875e08dc83c53f97bedf7b1))


### Unknown


* lint: add noqa comment — rjdbcm <rjdbcm@outlook.com>
([`8362a16`](https://github.com/OZI-Project/OZI.build/commit/8362a16d774778d32602bc15ce0fedb3e818385b))

* Create dev.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`02761de`](https://github.com/OZI-Project/OZI.build/commit/02761de1ae9d2aafb4457fdf87ecde4c774fe4a9))

## 1.10.5 (2025-01-20)


### Build system


* build(deps): bump OZI-Project/draft from 1.8.0 to 1.9.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.8.0 to 1.9.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/ae5afb49d75af6437247b504812f049e5607d342...31451b7f6a49b6ef70270b59ff70585d76677012)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0e40ed1`](https://github.com/OZI-Project/OZI.build/commit/0e40ed120a4c1a8e3c91c2a87518d7159b4cc2d3))

* build(deps): bump step-security/harden-runner from 2.10.3 to 2.10.4

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.3 to 2.10.4.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/c95a14d0e5bab51a9f56296a4eb0e416910cd350...cb605e52c26070c328afc4562f0b4ada7618a84e)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`da59965`](https://github.com/OZI-Project/OZI.build/commit/da59965361705b78294f69e75e78dc747296ced8))

## 1.10.4 (2025-01-19)


### Bug fixes


* fix: move requirements for release into repo root — rjdbcm <rjdbcm@outlook.com>
([`b0f0431`](https://github.com/OZI-Project/OZI.build/commit/b0f0431ee4493a828b83eed4d8c4a37eb4f57e41))

* fix: ignore TC001 — rjdbcm <rjdbcm@outlook.com>
([`79d567f`](https://github.com/OZI-Project/OZI.build/commit/79d567fd9b8c2113e3be7fbaec1ba05b127f8393))


### Build system


* build: update wrapfile to OZI 1.33 — rjdbcm <rjdbcm@outlook.com>
([`685adc7`](https://github.com/OZI-Project/OZI.build/commit/685adc748c46ab4c000d649c4460a9635a56ba7b))

* build: update brand assets — rjdbcm <rjdbcm@outlook.com>
([`1801567`](https://github.com/OZI-Project/OZI.build/commit/18015673333aa8b8816f3219d46193eb7554eed5))

* build(deps): bump actions/upload-artifact from 4.5.0 to 4.6.0

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.5.0 to 4.6.0.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/6f51ac03b9356f520e9adb1b1b7802705f340c2b...65c4c4a1ddee5b72f698fdd19549f0f0fb45cf08)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5f5e511`](https://github.com/OZI-Project/OZI.build/commit/5f5e511d9fc8662ef081e14e351fb6510d5ec2d3))

* build(deps): bump step-security/harden-runner from 2.10.2 to 2.10.3

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.2 to 2.10.3.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0080882f6c36860b6ba35c610c98ce87d4e2f26f...c95a14d0e5bab51a9f56296a4eb0e416910cd350)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3528da6`](https://github.com/OZI-Project/OZI.build/commit/3528da63720fdacfd5b905ad328910fd3b2e55c0))

* build(deps): bump github/codeql-action from 3.28.0 to 3.28.1

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.28.0 to 3.28.1.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/48ab28a6f5dbc2a99bf1e0131198dd8f1df78169...b6a472f63d85b9c78a3ac5e89422239fc15e9b3c)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c101dcd`](https://github.com/OZI-Project/OZI.build/commit/c101dcddbb666bacc79743d7cec32ebefd352651))

* build(deps): bump OZI-Project/publish from 1.7.3 to 1.8.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.3 to 1.8.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/fd7b8704941103ceec5a24f80d0999d2209ed8f2...025b6cb35f983387bb0981661eae0beddb8282fe)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e8783ae`](https://github.com/OZI-Project/OZI.build/commit/e8783ae3bd7e6bdd99265ff5fe1d04b4e2fd672c))

* build(deps): bump OZI-Project/checkpoint from 1.5.3 to 1.5.4

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.3 to 1.5.4.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/e8968b10918a82bf03e196f5feac1669ccdf98e2...84a85f725520d5661ed417915ccb0e769973879c)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b7acba5`](https://github.com/OZI-Project/OZI.build/commit/b7acba5d2190857aae2995ae069098b14e5b0247))

## 1.10.3 (2025-01-09)


### Build system


* build(deps): bump OZI-Project/checkpoint from 1.5.2 to 1.5.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.2 to 1.5.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/5af0476c5d335e70ea4c4338d25bc0561e6a781c...e8968b10918a82bf03e196f5feac1669ccdf98e2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c8b7428`](https://github.com/OZI-Project/OZI.build/commit/c8b7428c3f6d0596bf9f736a47792fbb3f70c32b))

* build(deps): bump OZI-Project/checkpoint from 1.5.1 to 1.5.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.5.1 to 1.5.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/fd28b35f0af00d1ec49a732b82409a1e386974ec...5af0476c5d335e70ea4c4338d25bc0561e6a781c)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8fda99a`](https://github.com/OZI-Project/OZI.build/commit/8fda99a7188615a4241d65f380bbe06456fe1ea1))

* build: sync tox requirements — rjdbcm <rjdbcm@outlook.com>
([`cf1a621`](https://github.com/OZI-Project/OZI.build/commit/cf1a621e727e86be07bc02e1e56be199cc47d82f))

* build: add pathvalidate build dep — rjdbcm <rjdbcm@outlook.com>
([`78064fb`](https://github.com/OZI-Project/OZI.build/commit/78064fb950b917c68e2286f265d1349d6e5ec710))

* build: update ozi wrapfile to 1.31 — rjdbcm <rjdbcm@outlook.com>
([`89fe038`](https://github.com/OZI-Project/OZI.build/commit/89fe0384d1cb80a858d94a6d5d0374d9d225b9ac))

* build(deps): bump OZI-Project/checkpoint from 1.4.0 to 1.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.4.0 to 1.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/5eb7b6ec9ba2eec71a0418270d92e9a6d81d285f...fd28b35f0af00d1ec49a732b82409a1e386974ec)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`3aae2d3`](https://github.com/OZI-Project/OZI.build/commit/3aae2d388457f587dbcc3fe5ad402984e2bd125f))

* build(deps): bump pygments from 2.18.0 to 2.19.1 in /doc

Bumps [pygments](https://github.com/pygments/pygments) from 2.18.0 to 2.19.1.
- [Release notes](https://github.com/pygments/pygments/releases)
- [Changelog](https://github.com/pygments/pygments/blob/master/CHANGES)
- [Commits](https://github.com/pygments/pygments/compare/2.18.0...2.19.1)


updated-dependencies:
- dependency-name: pygments
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f05c526`](https://github.com/OZI-Project/OZI.build/commit/f05c52658ab51b65d84b6eb17a55ce2890839cfb))

* build(deps): bump OZI-Project/draft from 1.7.0 to 1.8.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.7.0 to 1.8.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/c0d23e778c413e1f5c7ca9555a1ec190c9e48cbd...ae5afb49d75af6437247b504812f049e5607d342)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`55a9842`](https://github.com/OZI-Project/OZI.build/commit/55a9842446ad0611263776f459987fdc108abe61))

* build(deps): bump OZI-Project/publish from 1.7.2 to 1.7.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.2 to 1.7.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/67952e32de84496a2ed2729ffbc612a63d4ede47...fd7b8704941103ceec5a24f80d0999d2209ed8f2)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`86a2e75`](https://github.com/OZI-Project/OZI.build/commit/86a2e75036003ec62941fb4fae8467c42c52659f))


### Documentation


* docs: add print logo — rjdbcm <rjdbcm@outlook.com>
([`d639c97`](https://github.com/OZI-Project/OZI.build/commit/d639c97d84c0910fc8c85089095f5313378ed5e6))

* docs: add pdf title logo — rjdbcm <rjdbcm@outlook.com>
([`e7272aa`](https://github.com/OZI-Project/OZI.build/commit/e7272aa80cdb04531926eb5c635dea970f1bd912))

## 1.10.2 (2025-01-05)


### Build system


* build: update brand assets — rjdbcm <rjdbcm@outlook.com>
([`559e1e4`](https://github.com/OZI-Project/OZI.build/commit/559e1e4249761c652d8c5716acd32815a36b6f1e))


### Documentation


* docs: update title — rjdbcm <rjdbcm@outlook.com>
([`e97a98f`](https://github.com/OZI-Project/OZI.build/commit/e97a98f923f95984de6d193e97fbcb2f2009b2d7))


### Unknown


* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f04ad6c`](https://github.com/OZI-Project/OZI.build/commit/f04ad6c64aa8efc3eff90510417c8230fbf30b2a))

## 1.10.1 (2025-01-03)


### Build system


* build(deps): bump markupsafe from 2.1.5 to 3.0.2 in /doc

Bumps [markupsafe](https://github.com/pallets/markupsafe) from 2.1.5 to 3.0.2.
- [Release notes](https://github.com/pallets/markupsafe/releases)
- [Changelog](https://github.com/pallets/markupsafe/blob/main/CHANGES.rst)
- [Commits](https://github.com/pallets/markupsafe/compare/2.1.5...3.0.2)


updated-dependencies:
- dependency-name: markupsafe
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`1b50c3d`](https://github.com/OZI-Project/OZI.build/commit/1b50c3dafcaad6c24c7e4bbf73b4cfce9c352dd8))

* build(deps): bump docutils from 0.20.1 to 0.21.2 in /doc

Bumps [docutils](https://docutils.sourceforge.io) from 0.20.1 to 0.21.2.


updated-dependencies:
- dependency-name: docutils
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a030e5d`](https://github.com/OZI-Project/OZI.build/commit/a030e5dab0350ff50f8d9389edfc39359bf96165))

* build(deps): bump gitdb from 4.0.11 to 4.0.12 in /doc

Bumps [gitdb](https://github.com/gitpython-developers/gitdb) from 4.0.11 to 4.0.12.
- [Release notes](https://github.com/gitpython-developers/gitdb/releases)
- [Commits](https://github.com/gitpython-developers/gitdb/compare/4.0.11...4.0.12)


updated-dependencies:
- dependency-name: gitdb
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`a295d71`](https://github.com/OZI-Project/OZI.build/commit/a295d71f12b28707f2575718965226358b416478))

* build(deps): update alabaster requirement in /doc

Updates the requirements on [alabaster](https://github.com/sphinx-doc/alabaster) to permit the latest version.
- [Release notes](https://github.com/sphinx-doc/alabaster/releases)
- [Changelog](https://github.com/sphinx-doc/alabaster/blob/master/docs/changelog.rst)
- [Commits](https://github.com/sphinx-doc/alabaster/compare/0.7.1...0.7.16)


updated-dependencies:
- dependency-name: alabaster
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`8b8dfe6`](https://github.com/OZI-Project/OZI.build/commit/8b8dfe67488f9dd93b4c94c308bcc7bb63b8cb62))

* build(deps): bump sphinx from 7.2.6 to 7.4.7 in /doc

Bumps [sphinx](https://github.com/sphinx-doc/sphinx) from 7.2.6 to 7.4.7.
- [Release notes](https://github.com/sphinx-doc/sphinx/releases)
- [Changelog](https://github.com/sphinx-doc/sphinx/blob/v7.4.7/CHANGES.rst)
- [Commits](https://github.com/sphinx-doc/sphinx/compare/v7.2.6...v7.4.7)


updated-dependencies:
- dependency-name: sphinx
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e17e100`](https://github.com/OZI-Project/OZI.build/commit/e17e100ea00de86d82a3a996bf2e1a6a2f9225f9))

* build(deps): bump smmap from 5.0.1 to 5.0.2 in /doc

Bumps [smmap](https://github.com/gitpython-developers/smmap) from 5.0.1 to 5.0.2.
- [Release notes](https://github.com/gitpython-developers/smmap/releases)
- [Commits](https://github.com/gitpython-developers/smmap/compare/v5.0.1...v5.0.2)


updated-dependencies:
- dependency-name: smmap
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ac572e4`](https://github.com/OZI-Project/OZI.build/commit/ac572e45d4129024993a204f98ca169a235af6a2))

* build(deps): bump actions/dependency-review-action from 2.5.1 to 4.5.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 2.5.1 to 4.5.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/0efb1d1d84fc9633afcdaad14c485cbbc90ef46c...3b139cfc5fae8b618d3eae3675e383bb1769c019)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`4e5f061`](https://github.com/OZI-Project/OZI.build/commit/4e5f061a88f866f081975b3aff50d413cee8d12d))

* build(deps): bump step-security/harden-runner from 2.7.1 to 2.10.2

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.7.1 to 2.10.2.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/v2.7.1...0080882f6c36860b6ba35c610c98ce87d4e2f26f)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`aef615b`](https://github.com/OZI-Project/OZI.build/commit/aef615bae25af5f087695d96fa2ee166ae39740d))

* build(deps): bump actions/upload-artifact from 4.4.0 to 4.5.0

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.4.0 to 4.5.0.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/v4.4.0...6f51ac03b9356f520e9adb1b1b7802705f340c2b)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5a9a226`](https://github.com/OZI-Project/OZI.build/commit/5a9a22684c2cf8264681a748c2acd8112fb88cca))

* build(deps): bump actions/checkout from 3.6.0 to 4.2.2

Bumps [actions/checkout](https://github.com/actions/checkout) from 3.6.0 to 4.2.2.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/v3.6.0...11bd71901bbe5b1630ceea73d27597364c9af683)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`6ede881`](https://github.com/OZI-Project/OZI.build/commit/6ede881acc315acd1de2fa0c4b89b02212987745))

* build(deps): bump github/codeql-action from 2.25.4 to 3.28.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 2.25.4 to 3.28.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/v2.25.4...48ab28a6f5dbc2a99bf1e0131198dd8f1df78169)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`f8615eb`](https://github.com/OZI-Project/OZI.build/commit/f8615eb3d2af941683dad64eb31c9d8ebe5d0eea))

* build(deps): bump gitpython from 3.1.43 to 3.1.44 in /doc

Bumps [gitpython](https://github.com/gitpython-developers/GitPython) from 3.1.43 to 3.1.44.
- [Release notes](https://github.com/gitpython-developers/GitPython/releases)
- [Changelog](https://github.com/gitpython-developers/GitPython/blob/main/CHANGES)
- [Commits](https://github.com/gitpython-developers/GitPython/compare/3.1.43...3.1.44)


updated-dependencies:
- dependency-name: gitpython
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2cc0650`](https://github.com/OZI-Project/OZI.build/commit/2cc0650557c410a720258a56d4b970e20e2e31cb))

* build(deps): update ozi-build requirement from ~=1.9 to ~=1.10 in /doc


updated-dependencies:
- dependency-name: ozi-build
  dependency-type: direct:production
... — dependabot[bot] <support@github.com>
([`49d1c23`](https://github.com/OZI-Project/OZI.build/commit/49d1c234bcb87e5396be22134ccb0e9b54121df9))

* build(deps): bump meson[ninja] from 1.6.0 to 1.6.1 in /doc

Bumps [meson[ninja]](https://github.com/mesonbuild/meson) from 1.6.0 to 1.6.1.
- [Release notes](https://github.com/mesonbuild/meson/releases)
- [Commits](https://github.com/mesonbuild/meson/compare/1.6.0...1.6.1)


updated-dependencies:
- dependency-name: meson[ninja]
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f4e438f`](https://github.com/OZI-Project/OZI.build/commit/f4e438f267703587077ff152ed28208e47e35c3b))

* build(deps): bump click from 8.1.7 to 8.1.8 in /doc

Bumps [click](https://github.com/pallets/click) from 8.1.7 to 8.1.8.
- [Release notes](https://github.com/pallets/click/releases)
- [Changelog](https://github.com/pallets/click/blob/main/CHANGES.rst)
- [Commits](https://github.com/pallets/click/compare/8.1.7...8.1.8)


updated-dependencies:
- dependency-name: click
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f28699c`](https://github.com/OZI-Project/OZI.build/commit/f28699ce46f941ac24f230279748a1b5d3d45783))

* build(deps): bump pyparsing from 3.2.0 to 3.2.1 in /doc

Bumps [pyparsing](https://github.com/pyparsing/pyparsing) from 3.2.0 to 3.2.1.
- [Release notes](https://github.com/pyparsing/pyparsing/releases)
- [Changelog](https://github.com/pyparsing/pyparsing/blob/master/CHANGES)
- [Commits](https://github.com/pyparsing/pyparsing/compare/3.2.0...3.2.1)


updated-dependencies:
- dependency-name: pyparsing
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fdf392e`](https://github.com/OZI-Project/OZI.build/commit/fdf392e73106eef096c7fa670f021ebca274fa3d))


### Documentation


* docs: update copyright info — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`11f3d46`](https://github.com/OZI-Project/OZI.build/commit/11f3d4602b26843b93b926ac0dcba4e708e63341))

* docs: update branding assets — rjdbcm <rjdbcm@outlook.com>
([`186de8f`](https://github.com/OZI-Project/OZI.build/commit/186de8f2aa74b022314ca74e3b80d2d22b76454f))

* docs: add logo — rjdbcm <rjdbcm@outlook.com>
([`2d20fb1`](https://github.com/OZI-Project/OZI.build/commit/2d20fb152561add1d13f9f39b0e97b5a7d498cae))

* docs: fix link — rjdbcm <rjdbcm@outlook.com>
([`6889f05`](https://github.com/OZI-Project/OZI.build/commit/6889f05e210d241bc6b1fc143decfbdecbc00490))


### Unknown


* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c4fd6c3`](https://github.com/OZI-Project/OZI.build/commit/c4fd6c392e045aba87a8267cccacc591e28a527f))

* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`49fe05a`](https://github.com/OZI-Project/OZI.build/commit/49fe05a36261e1d736bc2e52676b740ef638d3ac))

* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`defbabf`](https://github.com/OZI-Project/OZI.build/commit/defbabf863d8151586afd014b212219963579ce4))

* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8339f34`](https://github.com/OZI-Project/OZI.build/commit/8339f34a1145fb54d7411e3e1af32897fc1e8cb7))

* [StepSecurity] Apply security best practices — StepSecurity Bot <bot@stepsecurity.io>
([`f7ad3a2`](https://github.com/OZI-Project/OZI.build/commit/f7ad3a27370ffb66631fa9eaca19fe0846ecd0b1))

* Update license.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5846776`](https://github.com/OZI-Project/OZI.build/commit/58467762f01f6c66c8ece8f3aa528a9cca5c8fc7))

* Update conf.py copyright — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`0eb70de`](https://github.com/OZI-Project/OZI.build/commit/0eb70de3c5263b3df05eae094c5e9463dca97024))

## 1.10.0 (2025-01-01)


### Bug fixes


* fix: build _does_ require some core tooling — rjdbcm <rjdbcm@outlook.com>
([`47bf1c0`](https://github.com/OZI-Project/OZI.build/commit/47bf1c037a260852510d4d8846ca3844da0ddc80))

* fix: remove core requirements from build-system — rjdbcm <rjdbcm@outlook.com>
([`0b0fe3e`](https://github.com/OZI-Project/OZI.build/commit/0b0fe3e756bea8787f305086ab9f5c0ed3b45795))


### Build system


* build: add project-urls — rjdbcm <rjdbcm@outlook.com>
([`481539f`](https://github.com/OZI-Project/OZI.build/commit/481539fbc7331c24080507980b9b092608d95bfa))

* build(deps): bump charset-normalizer from 3.4.0 to 3.4.1

Bumps [charset-normalizer](https://github.com/jawah/charset_normalizer) from 3.4.0 to 3.4.1.
- [Release notes](https://github.com/jawah/charset_normalizer/releases)
- [Changelog](https://github.com/jawah/charset_normalizer/blob/master/CHANGELOG.md)
- [Commits](https://github.com/jawah/charset_normalizer/compare/3.4.0...3.4.1)


updated-dependencies:
- dependency-name: charset-normalizer
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ad77836`](https://github.com/OZI-Project/OZI.build/commit/ad77836744fef25c6e5b6210fec0f7e0357bbed1))


### Features


* feat: add pathvalidate to ``OZI.build[core]`` option — rjdbcm <rjdbcm@outlook.com>
([`61e364a`](https://github.com/OZI-Project/OZI.build/commit/61e364a45a691b4b5b7e8be94c66701689ad8396))


### Unknown


* Update pyproject.toml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`3a35f63`](https://github.com/OZI-Project/OZI.build/commit/3a35f63b8f5a452acdc5d4155038502248591ef5))

* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`bea8cc1`](https://github.com/OZI-Project/OZI.build/commit/bea8cc1f44b9d70a841f5f015959dc76dbc778b7))

## 1.9.1 (2024-12-29)


### Unknown


* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`4a8883b`](https://github.com/OZI-Project/OZI.build/commit/4a8883bd8a2333f0abce111ae413e884bcac345c))

* Bump jinja2 in /doc in the pip group across 1 directory

Bumps the pip group with 1 update in the /doc directory: [jinja2](https://github.com/pallets/jinja).


Updates `jinja2` from 3.1.4 to 3.1.5
- [Release notes](https://github.com/pallets/jinja/releases)
- [Changelog](https://github.com/pallets/jinja/blob/main/CHANGES.rst)
- [Commits](https://github.com/pallets/jinja/compare/3.1.4...3.1.5)


updated-dependencies:
- dependency-name: jinja2
  dependency-type: direct:production
  dependency-group: pip
... — dependabot[bot] <support@github.com>
([`bfb743e`](https://github.com/OZI-Project/OZI.build/commit/bfb743ec54e6bf409d73c053b01ec48e259e9b6f))

* Update index.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`73614d8`](https://github.com/OZI-Project/OZI.build/commit/73614d889be65a894477cded2dca56da8c6c8b93))

## 1.9.0 (2024-12-27)


### Build system


* build: fix workflow — rjdbcm <rjdbcm@outlook.com>
([`877ca93`](https://github.com/OZI-Project/OZI.build/commit/877ca937ce8481634d35940b9936690ad52d89df))

* build: fix file permissions — rjdbcm <rjdbcm@outlook.com>
([`107a6ed`](https://github.com/OZI-Project/OZI.build/commit/107a6ed2e92f4630e450c9ffcedbb95698baa409))

* build: add .mypy_cache to .gitignore — rjdbcm <rjdbcm@outlook.com>
([`e418e77`](https://github.com/OZI-Project/OZI.build/commit/e418e77dc8937d68624e725f889c2ed0b732b4bb))

* build: fix release workflow — rjdbcm <rjdbcm@outlook.com>
([`3b4a58e`](https://github.com/OZI-Project/OZI.build/commit/3b4a58e2ecf7d8fb8685c92d514d44c47acb07c9))

* build: shorter custom workflow — rjdbcm <rjdbcm@outlook.com>
([`cd8fd46`](https://github.com/OZI-Project/OZI.build/commit/cd8fd46c9fc5d7eec73ab127fd7bd1cd3586afe7))

* build: correct artifact name — rjdbcm <rjdbcm@outlook.com>
([`731e5fd`](https://github.com/OZI-Project/OZI.build/commit/731e5fd345a231c1b82df5bcb4430fc418cc0fe7))

* build: use a custom workflow — rjdbcm <rjdbcm@outlook.com>
([`0167fd2`](https://github.com/OZI-Project/OZI.build/commit/0167fd20891af2b51b5966aa017e39a2e38c050e))

* build: correct name — rjdbcm <rjdbcm@outlook.com>
([`c20e4b2`](https://github.com/OZI-Project/OZI.build/commit/c20e4b215100fc362665c69428b7a0f744b65da4))

* build: fix changelog — rjdbcm <rjdbcm@outlook.com>
([`950537f`](https://github.com/OZI-Project/OZI.build/commit/950537f1cebfb52f3fafd5b21b9cb274fb604f56))

* build: remove master release branch pattern — rjdbcm <rjdbcm@outlook.com>
([`f96d21a`](https://github.com/OZI-Project/OZI.build/commit/f96d21af1b5fecfc121490f5c2b7d06374e6a932))

* build: dont compile to bytecode — rjdbcm <rjdbcm@outlook.com>
([`ab98233`](https://github.com/OZI-Project/OZI.build/commit/ab982330db5831a7ceca55f2d50f99ebab137d54))

* build: fix some docs typos — rjdbcm <rjdbcm@outlook.com>
([`57b482a`](https://github.com/OZI-Project/OZI.build/commit/57b482adc4ea9ae9d5e05f8c4e2217cb8893be6b))

* build: fix docs title — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`7f45cdb`](https://github.com/OZI-Project/OZI.build/commit/7f45cdb42c18c074055db20d2d0b81a5c8641c97))

* build: simplify docs — rjdbcm <rjdbcm@outlook.com>
([`fb34282`](https://github.com/OZI-Project/OZI.build/commit/fb342821c09a3c4534383be5182e983d5847c188))

* build: fix docs — rjdbcm <rjdbcm@outlook.com>
([`55d4358`](https://github.com/OZI-Project/OZI.build/commit/55d4358860f19250a4603ca001a25a669c3b79bd))

* build: add doc dependency — rjdbcm <rjdbcm@outlook.com>
([`d1e038a`](https://github.com/OZI-Project/OZI.build/commit/d1e038a75d78a0f5c6677c69e01bd4c6588f1116))

* build: add sphinx docs — rjdbcm <rjdbcm@outlook.com>
([`95994db`](https://github.com/OZI-Project/OZI.build/commit/95994db49582d61e2201ddec1b88da5a0962fedf))

* build: add release branches to workflow — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`39e1d7e`](https://github.com/OZI-Project/OZI.build/commit/39e1d7e810401d856db8f7d6376a01854bbc2826))

* build: fix dist checkpoint — rjdbcm <rjdbcm@outlook.com>
([`4dd9149`](https://github.com/OZI-Project/OZI.build/commit/4dd91499c3f354e25c99f9ccaa5e38da1936f945))

* build: fix wheel release — rjdbcm <rjdbcm@outlook.com>
([`eb02a41`](https://github.com/OZI-Project/OZI.build/commit/eb02a41c4c914b6007df54323c0dec2e783ed865))

* build: skip dist checkpoint — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`6a3a5e2`](https://github.com/OZI-Project/OZI.build/commit/6a3a5e2736587dabfd7fbe581881a7253a4c3d23))

* build: no tests for now — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`00af619`](https://github.com/OZI-Project/OZI.build/commit/00af619cfd2d33026531e2dd0085560356e6bd5b))

* build: main is a release branch — rjdbcm <rjdbcm@outlook.com>
([`9c2f19b`](https://github.com/OZI-Project/OZI.build/commit/9c2f19b9ad85cc63bcbdb01ee1ef3c71838e6908))

* build: use trusted publishing and dogfood OZI — rjdbcm <rjdbcm@outlook.com>
([`4268b0d`](https://github.com/OZI-Project/OZI.build/commit/4268b0db89ebbc1c2609c66a7ab93f8f0f069a10))

* build: run black — rjdbcm <rjdbcm@outlook.com>
([`153735b`](https://github.com/OZI-Project/OZI.build/commit/153735b18c4f6a3a9419a7555009980c35bb0bdc))

* build: run isort — rjdbcm <rjdbcm@outlook.com>
([`0fb8ecf`](https://github.com/OZI-Project/OZI.build/commit/0fb8ecf36e1025822d661deb60c816888ec36f1f))


### Documentation


* docs: enable colon fence — rjdbcm <rjdbcm@outlook.com>
([`3c3230a`](https://github.com/OZI-Project/OZI.build/commit/3c3230a4ebc1cd4276857d74dd263185468a0010))

* docs: use howto pdf theme — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`0e97756`](https://github.com/OZI-Project/OZI.build/commit/0e977563b305c1011896f1b2bceb32cf4115c997))

* docs: add changelog template — rjdbcm <rjdbcm@outlook.com>
([`2851d92`](https://github.com/OZI-Project/OZI.build/commit/2851d9259a629107498c705391d01a8796623064))

* docs: add changes and docs link — rjdbcm <rjdbcm@outlook.com>
([`fc7ea95`](https://github.com/OZI-Project/OZI.build/commit/fc7ea9513a2ac2033afa5ed86ba267891b937b9f))

* docs: add homepage link — rjdbcm <rjdbcm@outlook.com>
([`ac65d38`](https://github.com/OZI-Project/OZI.build/commit/ac65d383eceb0870dcbde2b6ffbab965572aeb40))


### Features


* feat: use OZI for publishing

Feat/dogfood ozi
([`485bd37`](https://github.com/OZI-Project/OZI.build/commit/485bd37accff05383ca5ce509f5331129eb5baa7))


### Unknown


* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`f9de2ad`](https://github.com/OZI-Project/OZI.build/commit/f9de2ade260ef378098e7ad93e8491e9516717a0))

* Update pyproject.toml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`3060ee8`](https://github.com/OZI-Project/OZI.build/commit/3060ee81c23a5ba581a7cd4374bd074e6be71f79))

* remove unused imports — rjdbcm <rjdbcm@outlook.com>
([`831bcb1`](https://github.com/OZI-Project/OZI.build/commit/831bcb1763297b7b571b63033e205288c08fe4f6))

* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`ce1842c`](https://github.com/OZI-Project/OZI.build/commit/ce1842cbe91a8f55c941d874cffde54e33984491))

* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`cd75012`](https://github.com/OZI-Project/OZI.build/commit/cd75012f6ab5e5292dec6870aed7f6800d327d10))

## 1.8.3 (2024-12-23)


### Unknown


* 1.8.3 revert get_requires_for_build_wheel changes to match specification — rjdbcm <rjdbcm@outlook.com>
([`949398f`](https://github.com/OZI-Project/OZI.build/commit/949398f13d706480455e3b87d1a98a7f436eab59))

## 1.8.2 (2024-12-19)


### Unknown


* 1.8.2: correct license-expression format — rjdbcm <rjdbcm@outlook.com>
([`f15af89`](https://github.com/OZI-Project/OZI.build/commit/f15af89107b10669a4d1ba62fead05682946d46d))

* 1.8.2: more flexible license metadata expectations — rjdbcm <rjdbcm@outlook.com>
([`a4fbe70`](https://github.com/OZI-Project/OZI.build/commit/a4fbe70532d2ae79e5e637bf1cb4979fa544cfa1))

* Update .codeclimate.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`c286d3f`](https://github.com/OZI-Project/OZI.build/commit/c286d3fb7cf44730f6f101ae15c151bd31c0a803))

## 1.8.1 (2024-12-11)


### Unknown


* 1.8.1 use compatible version pins — rjdbcm <rjdbcm@outlook.com>
([`0014659`](https://github.com/OZI-Project/OZI.build/commit/0014659d9cbebf20d06648069fc6ee6c391864da))

## 1.8.0 (2024-12-09)


### Unknown


* 1.8.0: add regexploit — rjdbcm <rjdbcm@outlook.com>
([`5dea24f`](https://github.com/OZI-Project/OZI.build/commit/5dea24f212615e69a4f9c45f15b8b0d532ea39b9))

## 1.7.2 (2024-12-05)


### Unknown


* fix missing modules — rjdbcm <rjdbcm@outlook.com>
([`46fb19d`](https://github.com/OZI-Project/OZI.build/commit/46fb19db51fd7a31eaaece246a890dd27ceeaba6))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`854cbb6`](https://github.com/OZI-Project/OZI.build/commit/854cbb6b08634f178fe6cc42e47b3dce42228208))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`638359d`](https://github.com/OZI-Project/OZI.build/commit/638359d837a3b8c21c83f53859afd1bcb9832df1))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`690d658`](https://github.com/OZI-Project/OZI.build/commit/690d6585ffdc76b8455537696e1a7d9d606797a6))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`7cd9916`](https://github.com/OZI-Project/OZI.build/commit/7cd99160020f75a17c54b0600efb8e7c3c8e8fde))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`3b5e3ae`](https://github.com/OZI-Project/OZI.build/commit/3b5e3ae6d0bf19d40023b93afe32402ae9b59427))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`384b812`](https://github.com/OZI-Project/OZI.build/commit/384b812a7baac3eff81857cbc3967b541793f940))

* refactor backend for future maintainability — rjdbcm <rjdbcm@outlook.com>
([`e0cd258`](https://github.com/OZI-Project/OZI.build/commit/e0cd25818d51ed90182052b1b45cab1cd91eff3d))

## 1.7.1 (2024-12-02)


### Unknown


* fix wheel format
([`a346d98`](https://github.com/OZI-Project/OZI.build/commit/a346d98843527d9c0500c59d9faefaa11b7f88cd))

* fix wheel format
([`7caac3d`](https://github.com/OZI-Project/OZI.build/commit/7caac3da5b5a7a82b7f8c94e79af3acd73fa087d))

* fix wheel format — rjdbcm <rjdbcm@outlook.com>
([`482acd9`](https://github.com/OZI-Project/OZI.build/commit/482acd92ff2f5292c15e62cd0191845536312fc1))

## 1.7.0 (2024-12-02)


### Unknown


* update docs and bump to 1.7 — rjdbcm <rjdbcm@outlook.com>
([`74c857e`](https://github.com/OZI-Project/OZI.build/commit/74c857e835961eb3feb8cda559d5f84bb623e9e8))

* add pyc_wheel config — rjdbcm <rjdbcm@outlook.com>
([`49eba52`](https://github.com/OZI-Project/OZI.build/commit/49eba529dc792d0469d72b70a569b8ad47638f1b))

* update license info — rjdbcm <rjdbcm@outlook.com>
([`3f5de5d`](https://github.com/OZI-Project/OZI.build/commit/3f5de5d931cd0b36c93581d2417c952df0da3ed7))

* refactor module
([`717f2b7`](https://github.com/OZI-Project/OZI.build/commit/717f2b7278bbe8fcd5c5e75bca5ce3e7854c0d65))

* refactor module — rjdbcm <rjdbcm@outlook.com>
([`11c5db6`](https://github.com/OZI-Project/OZI.build/commit/11c5db6bd081889d0489884444cf2d41450bc4f8))

* Update .codeclimate.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`1bf1e24`](https://github.com/OZI-Project/OZI.build/commit/1bf1e2465902b6ab42c13313f9065ccea998a918))

* Create .codeclimate.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`44fc266`](https://github.com/OZI-Project/OZI.build/commit/44fc2669fe20f3805d984f73eac6bd8bb1887bc4))

* remove redundant code — rjdbcm <rjdbcm@outlook.com>
([`cea922b`](https://github.com/OZI-Project/OZI.build/commit/cea922be91e7fc18b30153046e6f3609aa84f672))

* refactor convert_wheel — rjdbcm <rjdbcm@outlook.com>
([`f1e6073`](https://github.com/OZI-Project/OZI.build/commit/f1e607322719541acc53c38b0faad2a3588e7beb))

## 1.6.1 (2024-10-27)


### Unknown


* OZI.build 1.6.1: revert metadata version 2.4
([`50bb16b`](https://github.com/OZI-Project/OZI.build/commit/50bb16b091cd372836d2e2fa8566672c5d8a1625))

* OZI.build 1.6.1: metadata version 2.4 — rjdbcm <rjdbcm@outlook.com>
([`e3bca2c`](https://github.com/OZI-Project/OZI.build/commit/e3bca2ce743db4147fec12672c0d2eeb28366fcd))

* OZI.build 1.6.1: license and license-expression mutually exclusive — rjdbcm <rjdbcm@outlook.com>
([`7079d40`](https://github.com/OZI-Project/OZI.build/commit/7079d40fec00ef89edac02584405a832fbc25598))

* Fall back to metadata version 2.2 waiting on PyPI — rjdbcm <rjdbcm@outlook.com>
([`d11223d`](https://github.com/OZI-Project/OZI.build/commit/d11223d520058d2a3f8476ed1299a5b69df207a2))

* OZI.build 1.6: support for Metadata-Version 2.4 — rjdbcm <rjdbcm@outlook.com>
([`503558d`](https://github.com/OZI-Project/OZI.build/commit/503558d7cd2a6e727a8dd6e13d6fae9473f2363e))

* OZI.build 1.6: support for Metadata-Version 2.4 — rjdbcm <rjdbcm@outlook.com>
([`b4ca34f`](https://github.com/OZI-Project/OZI.build/commit/b4ca34ffdc6e5a4fe7d94702532bca8de3174eda))

* Update scorecards.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`5237e01`](https://github.com/OZI-Project/OZI.build/commit/5237e010d39808b821ac64221bbed8068a3bc081))

* Update scorecards.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`2193fb3`](https://github.com/OZI-Project/OZI.build/commit/2193fb382145d2f729b4c899069ec149324b1d83))

* Create SECURITY.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`1565436`](https://github.com/OZI-Project/OZI.build/commit/156543655aac5696d06bc1d7d92ac974080f1c86))

* Create dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`a428f3a`](https://github.com/OZI-Project/OZI.build/commit/a428f3a7dbfa9be1517fa518e1954e28a21a14c5))

* OZI.build 1.5.2: pyc_wheel compilation now sensitive to ``python.bytecompile`` meson option setting — rjdbcm <rjdbcm@outlook.com>
([`d452bf1`](https://github.com/OZI-Project/OZI.build/commit/d452bf1a6abdd6b3ed5061ea045c467e9d81f3e0))

## 1.5.1 (2024-09-04)


### Unknown


* 1.5.1 docs updated — rjdbcm <rjdbcm@outlook.com>
([`077db2c`](https://github.com/OZI-Project/OZI.build/commit/077db2c34892f55ba67f5cd99d8be2ce22bb7cdd))

## 1.5.0 (2024-09-01)


### Unknown


* OZI.build 1.5.0 expect a valid license file path to copy to dist-info
([`b5679f5`](https://github.com/OZI-Project/OZI.build/commit/b5679f5e119a8b0b013f3cbe1f6640a9baf0c47f))

* OZI.build 1.5.0 expect a valid license file path to copy to dist-info
([`c454c12`](https://github.com/OZI-Project/OZI.build/commit/c454c1227518678358540c20b0fed72e59da3570))

* OZI.build 1.5.0 expect a valid license file path to copy to dist-info
([`c94c1f6`](https://github.com/OZI-Project/OZI.build/commit/c94c1f6eb70ca467fe1a26d426d9ba487a8aa7ce))

* OZI.build 1.5.0 expect a valid license file path to copy to dist-info
([`855f14d`](https://github.com/OZI-Project/OZI.build/commit/855f14db18d219bcd501e5facda8c41d4020626b))

* OZI.build 1.5.0 expect a valid license file path to copy to dist-info — rjdbcm <rjdbcm@outlook.com>
([`caf6c95`](https://github.com/OZI-Project/OZI.build/commit/caf6c9555710d064e80067b6d587f71b5a2e0803))

## 1.4.3 (2024-08-28)


### Unknown


* OZI.build 1.4.3 update docs — rjdbcm <rjdbcm@outlook.com>
([`3cc5e81`](https://github.com/OZI-Project/OZI.build/commit/3cc5e81ce513900de62a2df0dde827c09f484c30))

## 1.4.2 (2024-08-28)


### Unknown


* OZI.build 1.4.2 fix requires-python override from config — rjdbcm <rjdbcm@outlook.com>
([`3f2eff9`](https://github.com/OZI-Project/OZI.build/commit/3f2eff91bcda7b275ea6e35976eb8b7efc632e35))

## 1.4.1 (2024-08-28)


### Unknown


* OZI.build 1.4.1 loosen requires-python — rjdbcm <rjdbcm@outlook.com>
([`351e459`](https://github.com/OZI-Project/OZI.build/commit/351e45972fa546391178ab7943e37fc43058ba96))

## 1.4.0 (2024-08-28)


### Unknown


* OZI.build 1.4.0 add pure-python-abi key — rjdbcm <rjdbcm@outlook.com>
([`63c3409`](https://github.com/OZI-Project/OZI.build/commit/63c34091aa22d90372095a8c8c8d3d702b5808b8))

* OZI.build 1.4.0 add packaging requirement and flexible Requires-Python setting — rjdbcm <rjdbcm@outlook.com>
([`a6a9b5a`](https://github.com/OZI-Project/OZI.build/commit/a6a9b5aef61fbcb781f2b53149923d8e9faf0c18))

* OZI.build 1.4.0 add packaging requirement and flexible Requires-Python setting — rjdbcm <rjdbcm@outlook.com>
([`6200763`](https://github.com/OZI-Project/OZI.build/commit/620076353dcd9cd92906e12ea8de15ea1fbf3aae))

* OZI.build 1.3.4: set Requires-Python: >=3.10, <3.13 — rjdbcm <rjdbcm@outlook.com>
([`ee004f3`](https://github.com/OZI-Project/OZI.build/commit/ee004f3d44c8c9de108fdcd9e7956c8a9d474114))

* OZI.build 1.3.3 add keywords metadata schema — rjdbcm <rjdbcm@outlook.com>
([`72b7a14`](https://github.com/OZI-Project/OZI.build/commit/72b7a14d18777b0226299c425027dbe1238114da))

## 1.3.2 (2024-08-26)


### Unknown


* OZI.build 1.3.2 fix alternate download url — rjdbcm <rjdbcm@outlook.com>
([`49d0ec0`](https://github.com/OZI-Project/OZI.build/commit/49d0ec0bb8a9c39f8968f6c7fbd45cc1a8944df9))

## 1.3.1 (2024-08-26)


### Unknown


* OZI.build 1.3.1 remove duplicate schema keys
([`2dd8660`](https://github.com/OZI-Project/OZI.build/commit/2dd866068fdac7819133e5311e96575cb9da296c))

## 1.3.0 (2024-08-26)


### Bug fixes


* fix: warn for ignoring nested keys
([`1b6e088`](https://github.com/OZI-Project/OZI.build/commit/1b6e088a1fcd23191cd3f4ca23ac826426d4b65a))

* fix: warn for ignoring nested keys — rjdbcm <rjdbcm@outlook.com>
([`d7a8d7e`](https://github.com/OZI-Project/OZI.build/commit/d7a8d7e2740a6dd60ba5fcf401d36dc740312d93))

* fix: ``project.optional_dependencies`` is parsed into wheel METADATA — rjdbcm <rjdbcm@outlook.com>
([`6933ce8`](https://github.com/OZI-Project/OZI.build/commit/6933ce8397bffd293ad07ae9b4c95ce01da765a1))


### Unknown


* OZI.build 1.3.0

changes target the 1.20 release of OZI and spec version 0.9
add the remaining metadata keys and deprecate ``requires`` — rjdbcm <rjdbcm@outlook.com>
([`e22afcd`](https://github.com/OZI-Project/OZI.build/commit/e22afcdf257e9d3c5d2f3704ebdf93d87c2c66c9))

* OZI.build 1.3.0

changes target the 1.20 release of OZI and spec version 0.9
add the remaining metadata keys and deprecate ``requires`` — rjdbcm <rjdbcm@outlook.com>
([`de14c71`](https://github.com/OZI-Project/OZI.build/commit/de14c7125f58c049edf4475b38a4ecbc6399df08))

* Fix metadata to insert extras after Name — rjdbcm <rjdbcm@outlook.com>
([`db4f98b`](https://github.com/OZI-Project/OZI.build/commit/db4f98b62fb21d7607466e12606fcba40d9d5c5f))

* OZI.build 1.2.3 - fix length check for real — rjdbcm <rjdbcm@outlook.com>
([`14bb45c`](https://github.com/OZI-Project/OZI.build/commit/14bb45c507e8941772bb345f15d81356762171de))

* OZI.build 1.2.2 - fix length check — rjdbcm <rjdbcm@outlook.com>
([`57e6e3f`](https://github.com/OZI-Project/OZI.build/commit/57e6e3fdac5498f5868a8400360011b9f9abb823))

* OZI.build 1.2.1 - proper support for OZI optional_dependencies when PKG-INFO metadata is supplied — rjdbcm <rjdbcm@outlook.com>
([`7aaea14`](https://github.com/OZI-Project/OZI.build/commit/7aaea14a98fc00e0af66c09438d380be5a89985a))

* OZI.build 1.2.0 — rjdbcm <rjdbcm@outlook.com>
([`b9a14fa`](https://github.com/OZI-Project/OZI.build/commit/b9a14fa73238466eef13688654e29e64ae324cf4))

* clarify warnings on string value for optional_dependencies — rjdbcm <rjdbcm@outlook.com>
([`5430af7`](https://github.com/OZI-Project/OZI.build/commit/5430af774d9a90096f168ecea4c0cbd55dcdfda7))

* added _parse_project_optional_dependencies to config — rjdbcm <rjdbcm@outlook.com>
([`e6c29c1`](https://github.com/OZI-Project/OZI.build/commit/e6c29c1817068b2b2bde17455f6b297fea377e86))

* warn about string as nested key
([`dcd8e92`](https://github.com/OZI-Project/OZI.build/commit/dcd8e9249e6e807099a6f4f655dec9b186e505c4))

* allow nested optional_dependencies — rjdbcm <rjdbcm@outlook.com>
([`0802c75`](https://github.com/OZI-Project/OZI.build/commit/0802c752981e9e8d602f2306e6a45ee379db24f9))

* OZI.build 1.1 uses build-system requires from ``ozi-spec`` — rjdbcm <rjdbcm@outlook.com>
([`a68c9b0`](https://github.com/OZI-Project/OZI.build/commit/a68c9b0d6cb5db45eb8c3d23fceb2e64c814e73d))

## 1.0.2 (2024-08-10)


### Unknown


* 1.0.2 fix duplicate name key in PKG-INFO — rjdbcm <rjdbcm@outlook.com>
([`7568db5`](https://github.com/OZI-Project/OZI.build/commit/7568db517f9fdfc2bda02d694206b6fae9351687))

## 1.0.1 (2024-08-09)


### Unknown


* 1.0.1: fix RECORD rewriting — rjdbcm <rjdbcm@outlook.com>
([`5685288`](https://github.com/OZI-Project/OZI.build/commit/56852886465a3519fdf26f17948ebe438ca29399))

## 1.0.0 (2024-08-06)


### Unknown


* OZI.build 1.0.0 — rjdbcm <rjdbcm@outlook.com>
([`bcbd784`](https://github.com/OZI-Project/OZI.build/commit/bcbd784072453060db1869fccdc272aad0d05c6b))

* OZI.build 1.0.0 — rjdbcm <rjdbcm@outlook.com>
([`15cbc0d`](https://github.com/OZI-Project/OZI.build/commit/15cbc0d176398fb7ec401c6f8dec7b3ec33ab152))

* OZI.build 1.0.0 — rjdbcm <rjdbcm@outlook.com>
([`92a23ae`](https://github.com/OZI-Project/OZI.build/commit/92a23aeaf8a13d3d8d0ed9f01df7a567514056d7))

* 0.0.27: fix wheel abi tag setting — rjdbcm <rjdbcm@outlook.com>
([`69fa379`](https://github.com/OZI-Project/OZI.build/commit/69fa37912cf3103866a5f0e36b71fba13e58af85))

* 0.0.26: normalize dist-info
([`14fa596`](https://github.com/OZI-Project/OZI.build/commit/14fa5962435b6e3bf2875e461cc6c6616227c938))

* 0.0.25: renormalize wheel name only. — rjdbcm <rjdbcm@outlook.com>
([`bc08072`](https://github.com/OZI-Project/OZI.build/commit/bc080725d9b5230478c10962ea20c5f9a066f387))

* 0.0.24: revert normalize project name
([`ede285c`](https://github.com/OZI-Project/OZI.build/commit/ede285c20408edf873ebe318e41cdaeac3a11f8b))

* 0.0.23: normalize project name for dist-info
([`4a280bd`](https://github.com/OZI-Project/OZI.build/commit/4a280bda222dce0da311ea07f7416e46c119dc0c))

* 0.0.22: revert normalize project name for filenames
([`a47d8dd`](https://github.com/OZI-Project/OZI.build/commit/a47d8ddb86ade554c1761bc696f9b54714bc6344))

* 0.0.21: normalize project name for filenames
([`2810778`](https://github.com/OZI-Project/OZI.build/commit/28107783b70c42c3ea6e1ce0cf595278d2512d26))

* 0.0.21: normalize project name for filenames
([`0a4bbe9`](https://github.com/OZI-Project/OZI.build/commit/0a4bbe9126166441a5bd387de5254d571c68876a))

* 0.0.21: normalize project name for filenames
([`2cbbb69`](https://github.com/OZI-Project/OZI.build/commit/2cbbb69a19fd7ef51ba8a0347c05f5267030543d))

* 0.0.21: normalize project name for filenames
([`7c849e2`](https://github.com/OZI-Project/OZI.build/commit/7c849e26f715f29c8a439b1dbbc5af1c1050c8d7))

* 0.0.21: normalize project name for filenames
([`6f31361`](https://github.com/OZI-Project/OZI.build/commit/6f313614ecf5347fe610c05ef4a40eae6e9c8e2b))

* 0.0.21: normalize project name for filenames — rjdbcm <rjdbcm@outlook.com>
([`c948efd`](https://github.com/OZI-Project/OZI.build/commit/c948efdae79c57c87fa642725a68ccad3c5c127e))

* 0.2.0
([`fc3494e`](https://github.com/OZI-Project/OZI.build/commit/fc3494ec94effe4830fcf0239ee49d9848ab13aa))

* 0.0.19 update metadata
([`06d7855`](https://github.com/OZI-Project/OZI.build/commit/06d7855e10177c04eb2f714a63e3ee78c17e6e6c))

* 0.0.19 update metadata
([`a62840d`](https://github.com/OZI-Project/OZI.build/commit/a62840d7957345dd0221705c3e97dd46769c17ab))

## 0.0.18 (2024-05-11)


### Unknown


* [StepSecurity] Apply security best practices — StepSecurity Bot <bot@stepsecurity.io>
([`f17a780`](https://github.com/OZI-Project/OZI.build/commit/f17a7809e304ff947ca813d15263a4fee04e46b4))

* 0.0.18
([`b51793c`](https://github.com/OZI-Project/OZI.build/commit/b51793c55482c7fd8ec2a1c6b469758fbb6b9929))

* 0.0.18: fix typo in docs.
([`cb669f1`](https://github.com/OZI-Project/OZI.build/commit/cb669f1fa2a29c1aa7553dd99db7fcd8efe90503))

## 0.0.17 (2024-05-11)


### Unknown


* 0.0.17: updated release script.
([`a50e64c`](https://github.com/OZI-Project/OZI.build/commit/a50e64cdef65388aac3039f1487e83ab2e791d30))

* 0.0.17: updated release script.
([`e4d06e2`](https://github.com/OZI-Project/OZI.build/commit/e4d06e22157f826950069252c42f1b112bd37cca))

* 0.0.17: updated documentation.
([`1079842`](https://github.com/OZI-Project/OZI.build/commit/10798424278ef618a1610601598a5170f96f721b))

## 0.0.16 (2024-05-11)


### Unknown


* 0.0.16: summary key no longer required in metadata.
([`f128779`](https://github.com/OZI-Project/OZI.build/commit/f1287793ef8d1601aea966ac967e7d49f553e1b9))

## 0.0.15 (2024-05-04)


### Unknown


* 0.0.15: remove dependency on distutils.
([`ac60887`](https://github.com/OZI-Project/OZI.build/commit/ac60887b63c7618ab8b2a5f726b7d4074a4b6453))

## 0.0.14 (2024-05-04)


### Unknown


* vendor our pyc_wheel
([`910ea52`](https://github.com/OZI-Project/OZI.build/commit/910ea52e63bce6b310b59d5e13f2e5bd9b64f51d))

* vendor our pyc_wheel
([`4dc69ef`](https://github.com/OZI-Project/OZI.build/commit/4dc69ef6206af869733caa39cdfe5304be588128))

* vendor our pyc_wheel
([`982704c`](https://github.com/OZI-Project/OZI.build/commit/982704c2f1fd4d34dd13f76fcd3be35f54d6457e))

* vendor our pyc_wheel
([`0909c93`](https://github.com/OZI-Project/OZI.build/commit/0909c9363bceff6f291e2fcc31cede14f8fb044e))

* vendor our pyc_wheel
([`db8c821`](https://github.com/OZI-Project/OZI.build/commit/db8c821d56dbab056781bf31107e1eb0b0d35de6))

* vendor our pyc_wheel
([`5e67405`](https://github.com/OZI-Project/OZI.build/commit/5e67405c95f79a50184f33de69a0d4aaaa7a3e1e))

* vendor our pyc_wheel
([`56a8363`](https://github.com/OZI-Project/OZI.build/commit/56a8363b64acf3394f9b027991dfc95d9578d112))

* vendor our pyc_wheel
([`103c1be`](https://github.com/OZI-Project/OZI.build/commit/103c1be6714599ae3d11f85a66f336574b969f6a))

* vendor our pyc_wheel
([`0565f0c`](https://github.com/OZI-Project/OZI.build/commit/0565f0c808878abaf64a0b7cc47cd4adc8537806))

* vendor our pyc_wheel
([`6f95f07`](https://github.com/OZI-Project/OZI.build/commit/6f95f078e801597d3ff25f2a51d22ab8268cac86))

* vendor our pyc_wheel
([`8090351`](https://github.com/OZI-Project/OZI.build/commit/8090351f81cd53eb0a9e455de9ea61917b7b2370))

* vendor our pyc_wheel
([`e021209`](https://github.com/OZI-Project/OZI.build/commit/e0212092fecb3a58b1bd8fa93b2f7cee02dda88f))

* vendor our pyc_wheel
([`9a1564e`](https://github.com/OZI-Project/OZI.build/commit/9a1564e0f1938b1ed4fd53a21271ccc9834579dc))

* vendor our pyc_wheel
([`5fd54cc`](https://github.com/OZI-Project/OZI.build/commit/5fd54ccf0951fdd675fc6586ec5cc59c0708913a))

* vendor our pyc_wheel
([`bf6fe60`](https://github.com/OZI-Project/OZI.build/commit/bf6fe60cbee2186cdbb88650d302d2dad83f58cb))

* vendor our pyc_wheel
([`0ce0122`](https://github.com/OZI-Project/OZI.build/commit/0ce01223c47a655ea56e16f12b21d99606194015))

* vendor our pyc_wheel
([`fce333a`](https://github.com/OZI-Project/OZI.build/commit/fce333ad782e964f211ce2356bc4909df67b0354))

* vendor our pyc_wheel
([`1cec55d`](https://github.com/OZI-Project/OZI.build/commit/1cec55d86bca8419ba39fd0cb4c405254e232dd4))

* 0.0.13: fix for metadata generation in-situ
([`0a4dac4`](https://github.com/OZI-Project/OZI.build/commit/0a4dac406deaa40186a9b1624f4975dba38e8e96))

## 0.0.12 (2024-05-03)


### Unknown


* 0.0.12: fix for metadata generation in-situ
([`d584d72`](https://github.com/OZI-Project/OZI.build/commit/d584d72214a0e7c18c79172e454bed2d95ba6444))

* 0.0.12: fix for metadata generation in-situ
([`891c95d`](https://github.com/OZI-Project/OZI.build/commit/891c95dc2e3a6af1efc3eb3bb2f90ce1f9e4cc72))

* 0.0.12: fix for metadata generation in-situ
([`c748490`](https://github.com/OZI-Project/OZI.build/commit/c7484900225a46046892a7475025a402e357378a))

* 0.0.12: fix for metadata generation in-situ
([`d899606`](https://github.com/OZI-Project/OZI.build/commit/d899606ddc972b272dfa1a8c680bf6b83156bbb4))

## 0.0.11 (2024-05-03)


### Unknown


* 0.0.11: fix for metadata generation in-situ
([`b6b713d`](https://github.com/OZI-Project/OZI.build/commit/b6b713d0b1761bb9b3d1c28fc24255124ab7a965))

## 0.0.10 (2024-05-03)


### Unknown


* Update meson.build — Eden Rose, MSc <rjdbcm@outlook.com>
([`75b8956`](https://github.com/OZI-Project/OZI.build/commit/75b8956aab83d983600ce48e3b262f4db9b76fd5))

* Update buildapi.py - configure a builddir if one does not exist. — Eden Rose, MSc <rjdbcm@outlook.com>
([`ba83fcd`](https://github.com/OZI-Project/OZI.build/commit/ba83fcdc182acb9360ef7ea17a1193bfa3a35036))

* Update README.rst — Eden Rose, MSc <rjdbcm@outlook.com>
([`a7b7a67`](https://github.com/OZI-Project/OZI.build/commit/a7b7a67b92d2f170d7b37505947e71457ca36093))

* 0.0.9: fix OZI compiled wheel tagging.
([`9377d1d`](https://github.com/OZI-Project/OZI.build/commit/9377d1de1dd038e0636f10502bcc78a21499fbdd))

## 0.0.9 (2024-05-02)


### Unknown


* 0.0.9: fix OZI compiled wheel tagging.
([`b7f19e5`](https://github.com/OZI-Project/OZI.build/commit/b7f19e5be8d5d50cb721e6d15b07c92a5d96fe77))

* Update buildapi.py — Eden Rose, MSc <rjdbcm@outlook.com>
([`7693a8e`](https://github.com/OZI-Project/OZI.build/commit/7693a8e502f5c0765b63caa136b3a31149dc370f))

* 0.0.8
([`8ba7f0c`](https://github.com/OZI-Project/OZI.build/commit/8ba7f0cca250aff874ee3505c98fd35257d23db8))

* 0.0.8: fix PKG-INFO rendering in build wheel from sdist.
([`b1d93f7`](https://github.com/OZI-Project/OZI.build/commit/b1d93f7c0ac8afd35b5112499e4ad6ff4d628587))

* Update buildapi.py - fix for no argument ``python -m build`` — Eden Rose, MSc <rjdbcm@outlook.com>
([`44ee148`](https://github.com/OZI-Project/OZI.build/commit/44ee148a253fa29d88e1b4c848b71881afc6e410))

* 0.0.7: remove PKG-INFO rendering.
([`e96b2a7`](https://github.com/OZI-Project/OZI.build/commit/e96b2a7cce31ca86f02290e8bf380bf31bebda53))

* 0.0.7: remove PKG-INFO rendering.
([`7c7d4d7`](https://github.com/OZI-Project/OZI.build/commit/7c7d4d76ddddb145f1d613756f492c75d580c55e))

## 0.0.6 (2024-05-01)


### Unknown


* 0.0.6
([`39a2fa7`](https://github.com/OZI-Project/OZI.build/commit/39a2fa7945a6738687a7f16ec08d7a6456092eed))

* default to --no-tests in dist call.
([`c6b850d`](https://github.com/OZI-Project/OZI.build/commit/c6b850ddc50aeca2e8d881b1865a043a58fc7ee7))

## 0.0.5 (2024-05-01)


### Unknown


* 0.0.5
([`187b8f2`](https://github.com/OZI-Project/OZI.build/commit/187b8f2de4e0e5cda9ffe466b7527306e83c645d))

* meson-python-option-name works as described in docs
([`2507d8a`](https://github.com/OZI-Project/OZI.build/commit/2507d8a2eb10565cb60a3d925a0a8600371941a9))

## 0.0.4 (2024-05-01)


### Unknown


* 0.0.4
([`46e752b`](https://github.com/OZI-Project/OZI.build/commit/46e752b7d9be1644bcab267d73a8a34e32ddacce))

* optimize.
([`47a5dfb`](https://github.com/OZI-Project/OZI.build/commit/47a5dfbf5742c65ff6a61b3e57e81920b553520d))

* optimize.
([`a580659`](https://github.com/OZI-Project/OZI.build/commit/a580659a3d2914404d5398521eefd350f59a9490))

* run black.
([`85f0ed6`](https://github.com/OZI-Project/OZI.build/commit/85f0ed6f829641130939fc0d1fcb13b553dd6277))

* fix Debian incompatibility, always build with abi tag per OZI spec.
([`a2d63ee`](https://github.com/OZI-Project/OZI.build/commit/a2d63ee400c9768ee8e0c8e149bbf3c97935d8aa))

## 0.0.3 (2024-04-30)


### Unknown


* 0.0.3: add automatic detection of python dist version if requires-python is not set
([`88c2557`](https://github.com/OZI-Project/OZI.build/commit/88c25570baad2f86505bb76ea8df300fb079b039))

* clean up file lint
([`4bf8a09`](https://github.com/OZI-Project/OZI.build/commit/4bf8a09b5896d0cb80d520e7229c7343d7a033fa))

## 0.0.2 (2024-04-30)


### Continuous integration


* ci: Update to debian buster
([`cc0b0c0`](https://github.com/OZI-Project/OZI.build/commit/cc0b0c01163730aecd6fc938120789a343269460))


### Unknown


* fix wheel build on debian
([`33acef1`](https://github.com/OZI-Project/OZI.build/commit/33acef16d7e8a413e94f760c6d07b0dba87b7db6))

* fix wheel build on debian
([`ce339fa`](https://github.com/OZI-Project/OZI.build/commit/ce339faeed578f555dad3a32a99895eeebb9be38))

* bump
([`76078d7`](https://github.com/OZI-Project/OZI.build/commit/76078d7a8628463070f4d8a99a180182b6e234c5))

* dummy commit
([`cb7cedc`](https://github.com/OZI-Project/OZI.build/commit/cb7cedc1efeaa69b64ae9611e09174e7ccaa8059))

* bootstrap build
([`f934c7e`](https://github.com/OZI-Project/OZI.build/commit/f934c7ea8152ea58a7446dca862460f78404e90e))

* Pin requires.
([`a7fbd78`](https://github.com/OZI-Project/OZI.build/commit/a7fbd7820032a162cd36ab6fe0eb9060195a9b40))

* add fs import.
([`0f12de3`](https://github.com/OZI-Project/OZI.build/commit/0f12de38e1889a4443e7d150e2539b2229500c98))

* fix doc missed commit
([`f15de38`](https://github.com/OZI-Project/OZI.build/commit/f15de38d9c88accdf2afb4a872e127447013c4ff))

* also copyfile.
([`dcab9a8`](https://github.com/OZI-Project/OZI.build/commit/dcab9a8858dc9bc83568ad06655fb6f02aafabb5))

* fix typo
([`cbd5c7a`](https://github.com/OZI-Project/OZI.build/commit/cbd5c7a4eeb3c20abe0557fa18250ef94e15c5bd))

* Fix name.
([`f8a4b82`](https://github.com/OZI-Project/OZI.build/commit/f8a4b8228302e5c39d33bd746bf81d1131b5950b))

* bump version
([`42b28bc`](https://github.com/OZI-Project/OZI.build/commit/42b28bce4b97c4be6a3ec81ef13b6760faf03ee4))

* Fix maintainer-email
([`3ed30c2`](https://github.com/OZI-Project/OZI.build/commit/3ed30c21c8267e4cfe59d3e5f6c9b40a74f6b6d8))

* Update publishing metadata
([`a69f717`](https://github.com/OZI-Project/OZI.build/commit/a69f717ec4a46d869b412e56feddb7ba2f705634))

* Update to our own version.
([`3551ecc`](https://github.com/OZI-Project/OZI.build/commit/3551ecc79f4a3e3d7929e0843a2790ae60b5884e))

* Fix typo
([`4161065`](https://github.com/OZI-Project/OZI.build/commit/4161065b88b45200b00ccf59dd34a89543804982))

* Update buildapi.py - read pyproject as bytes. — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`91783e7`](https://github.com/OZI-Project/OZI.build/commit/91783e7709293155085fa38dcfe51b505686aee1))

* use toml.loads (load as string) — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`3bca7db`](https://github.com/OZI-Project/OZI.build/commit/3bca7db82062266a6c83aa40800db79cc6717373))

* Update buildapi.py - use tomllib or tomli — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`4410966`](https://github.com/OZI-Project/OZI.build/commit/4410966101ebad5a3bf03d4ea1b4f977cb073e8b))

* Update buildapi.py — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`30d3ab7`](https://github.com/OZI-Project/OZI.build/commit/30d3ab77309d7c3b86f8b227c2f9a33471de9617))

* Remove docs from build. — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`a14f3e6`](https://github.com/OZI-Project/OZI.build/commit/a14f3e686be3190d7adc75a9ff17c376bd2ffd81))

* Force rollback to 0.2
([`896b4ef`](https://github.com/OZI-Project/OZI.build/commit/896b4ef90c3cf80337ba7666908fd530bfb3f37a))

* Update buildapi.py — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`be5989c`](https://github.com/OZI-Project/OZI.build/commit/be5989cb36aa9aba43e160b8fa4db68f1bc06bba))

* Update buildapi.py — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`b84bafd`](https://github.com/OZI-Project/OZI.build/commit/b84bafd91b12e1ead13fe912ce7efa3504025af2))

* Update buildapi.py — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`69e45a4`](https://github.com/OZI-Project/OZI.build/commit/69e45a445ec78465bba8e92e66c02c8f9be07b3a))

* Update buildapi.py - use tomli — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`a74e33f`](https://github.com/OZI-Project/OZI.build/commit/a74e33ff0456481b46139995a3bc9d792a89fb20))

* Update meson.build — Eden Rose, MSc <42073607+rjdbcm@users.noreply.github.com>
([`13996fc`](https://github.com/OZI-Project/OZI.build/commit/13996fc67b0a9ac12815cc21df95adf5ea32c3f4))

* Fix zip slip path traversal.
([`73acacf`](https://github.com/OZI-Project/OZI.build/commit/73acacf3877efd590f59d0dc1b9bdfa90ac1d92f))

* Update meson.build
([`386205a`](https://github.com/OZI-Project/OZI.build/commit/386205a57cc0125e7206bba4b9420f15173b5d62))

* Use same interpreter as mesonpep for build
([`fe3b008`](https://github.com/OZI-Project/OZI.build/commit/fe3b0086a11503d426500157ca8eb8b6822e1780))

* Use meson-python-option-name when calling meson
([`38964b2`](https://github.com/OZI-Project/OZI.build/commit/38964b2ec1cd2e5cb80cef2f10eea9102710c849))

* Fix get_platform usage
([`5bc2728`](https://github.com/OZI-Project/OZI.build/commit/5bc2728275a3e13767b771f3b61068d0e0b94744))

* Use packaging and wheel instead of pep425tags
([`a798c32`](https://github.com/OZI-Project/OZI.build/commit/a798c32d1a58466b166bb11f54c3b5bf96b581ee))

* Re add meson-options running meson configure

This broke during refactoring to make use of config_settings
([`aabe01e`](https://github.com/OZI-Project/OZI.build/commit/aabe01e993b87769860741b25d124f9c3fa0c8f2))

* Include subprojects in dist tarballs

Avoiding to redownload them when rebuilding
([`b1acebc`](https://github.com/OZI-Project/OZI.build/commit/b1acebc70b6d2e288c6b9ed76cefabd756490a47))

* Fix format of license field in pyproject.toml

PEP621 says that this must be a table with either a text field or a
license field.

Fixes https://gitlab.com/thiblahute/mesonpep517/-/issues/13
([`a11ee77`](https://github.com/OZI-Project/OZI.build/commit/a11ee772513071198d02d555ac26a3c32e10608f))

* Use requires-python differently to construct the wheel tag

PEP 621 and the mesonpep517 documentation specify that requires-python
takes a string of version specifiers denoting the python versions that
the source code is compatible with.  So we cannot use the string
provided by the user verbatim for the wheel tag (the Tag: field in the
WHEEL metadata and part of the wheel's filename).  It needs to be parsed
and processed first.

* Add packaging as a dependency so that we can parse the requirs-python
  version specifiers
* _write_wheel_file() changes:
  * Move creation of the Tag: field into the template.
  * Make getting and formatting the wheel tag the caller's
    responsibility (the caller can make use of the get_wheel_tag()
    which fixes the Tag: field being populated with information about
    the python which ran mesonpep517 instead of the python the user
    specified for building the wheel)
* Add NoPythonVersion exception which is thrown when the requires-python
  field eliminates all python versions (for instance `requires-python:
  >=3,<=2`)
* New function python_major_support(python_requirements):
  * Takes the string of python requirements specifiers (as given by the
    user in python-requires) and decides whether py2 and or py3 are
    supported.
  * this uses the packaging module to parse the specifiers and then
    loops through them, figuring out whether python2 and/or python3 are
    marked as compatible.  Caveats/cornercase behaviours of the present
    code:
    * If no python-requires is given, then the code returns that it is
      compatible with both python2 and python3.
    * If neither py2 or py3 are marked as compatible by what's specified
      in python-requires, then raises NoPythonVersion exception so the
      user can fix their python-requires line.
  * Log a warning when requires-python is specified using `py2` or `py3`.
    Version specifiers should be used instead.
* New function get_wheel_tag(config, is_pure):
  * This is a combination of code from _write_wheel_file() and
    WheelBuilder.build().
  * It constructs the complete wheel tag (python implementation (and
    implementation version), python abi, and platform.
  * Now handles pure python code that runs under both py2 and py3
    (`p2.py3`).
  * Note: Does not catch NoPythonVersion exception... Should we catch
    these and give the user an abbreviated error in this project or is
    a traceback good enough?
  * Wheel tag for compiled extensions are slightly better than before.
    Now, both the wheel tag and filename will use the python that we're
    building with for the implementation and abi fields.  Caveats:
    * Platform does not take into account manylinux.
    * Cross compilation (I think that meson itself supports cross
      compilation) is not accounted for in any of the tags.  The
      python for the cross compile target will likely not run locally so
      we'd have to do something completely different for that.
  * Log lack of meson-python-option-name at info or higher.  Previously
    it was logged as a warning but only for non-pure builds.
* prepare_metadata_for_build_wheel() and WheelBiuulder.biuld() now get
  the wheel tag via get_wheel_tag().  This way, the wheel tag will be
  the same in both the WHEEL file's Tag: field and in the wheel's filename.
* pyproject.toml:
  * Add packaging to the list of dependencies
  * change the requires-python: format to use a version specifier as
    specified in PEP-621
* Config.get_metadata():
  * Add Requires-Python to the distinfo/METADATA

This fixes the issues with `requires-python` from:
https://gitlab.com/thiblahute/mesonpep517/-/merge_requests/13

This addresses the transformation of requires-python as a specifier to a
wheel tag which was noted as a blocker on this MR:
https://gitlab.com/thiblahute/mesonpep517/-/merge_requests/10#note_634888717
([`0431b79`](https://github.com/OZI-Project/OZI.build/commit/0431b799d8e6d8d3201171edbd83a30f9fa60575))

* Add missing PEP 621 fields to schema.py
([`34e7261`](https://github.com/OZI-Project/OZI.build/commit/34e7261d8d544cf8ddc3b53a1dd126dec53156bf))

* doc: Move 'meson-options' documentation to the scheme
([`2d99046`](https://github.com/OZI-Project/OZI.build/commit/2d990468766f0e4241a2f3aa20ff89a40c7faf54))

* Port metadata format to pep621

https://www.python.org/dev/peps/pep-0621 standardizes the fields for the
metadata to be used by pep517 backend so we should use them.

This deprecates our own format for now but keeps working with them
warning about deprecations.

Fixes https://gitlab.com/thiblahute/mesonpep517/-/issues/8
([`c52fb7d`](https://github.com/OZI-Project/OZI.build/commit/c52fb7dbbc11704db8b6438236254410b6e4ca6b))

* Use build instead of pep517 for build frontend

Community is throwing support around build and is more maintained than
pep517.
([`beae30f`](https://github.com/OZI-Project/OZI.build/commit/beae30f838437380c4ab3881ad9b5976853899d1))

* Use config_settings given from PEP517 frontends

config_settings allow users to pass arbitrary settings to build
backends. In this case, we are doing a pass-through straight to Meson.
([`391d7f4`](https://github.com/OZI-Project/OZI.build/commit/391d7f4ee1204538f35cf774c6b0a61381ae4773))

* Fix get_abi tag
this was creating issue's like having a `\r` in abi tag and erroring out
on windows
([`b71281f`](https://github.com/OZI-Project/OZI.build/commit/b71281f0b0a9831293a17034ef575d78decb4294))

* Release 0.2
([`8b0c691`](https://github.com/OZI-Project/OZI.build/commit/8b0c6919166e11e21754a745f48e9c6f1381c0dc))

* Refer to PEP 639 in 'license' field description — Christopher Arndt <chris@chrisarndt.de>
([`3827f3f`](https://github.com/OZI-Project/OZI.build/commit/3827f3f5e80ae5306da7c977b4a5a319a24322fd))

* Add 'maintainer' and 'maintainer-email' metadata fields support — Christopher Arndt <chris@chrisarndt.de>
([`8ea55ae`](https://github.com/OZI-Project/OZI.build/commit/8ea55ae4b71f69afa55f3f7aa3728797b51c5e62))

* Add support for 'license' metadata field — Christopher Arndt <chris@chrisarndt.de>
([`f1bdc2d`](https://github.com/OZI-Project/OZI.build/commit/f1bdc2d84e0dcd91c2e05c8448fb3b7088b2f724))

* Fix writing Tag in WHEEL file in wheel — Christopher Arndt <chris@chrisarndt.de>
([`aba9da6`](https://github.com/OZI-Project/OZI.build/commit/aba9da6aad95288ac43322ffdc38afb84833b087))

* Metadata schema streamlining

* Sort schema dict by metadata field key
* Mark required metadata fields instead of optional ones — Christopher Arndt <chris@chrisarndt.de>
([`b1b6d2b`](https://github.com/OZI-Project/OZI.build/commit/b1b6d2bb6047cd04798bacaca3d1d6b8d12aef5e))

* Make readme mime-type detection a bit more robust — Christopher Arndt <chris@chrisarndt.de>
([`ef07375`](https://github.com/OZI-Project/OZI.build/commit/ef0737503d6fcd5d1400730a2c63671a1761bb84))

* Put needed parts of 'wheel.pep425tags' into new 'pep425tags' submodule

'wheel.pep425tags' is unavailable in 'wheel>=0.35'

* Include attribution and license from 'wheel' project.
* Include new 'pep425tags.py' file in meson build.

Fixes: #5 — Christopher Arndt <chris@chrisarndt.de>
([`13ac5db`](https://github.com/OZI-Project/OZI.build/commit/13ac5db2d47bfc51ad3989d9f7381255cb0720fa))

* Simplify METADATA writing

* Fix KeyError when optional 'home-page' metadata field not present.
* Write not-strictly-required fields to METADATA dynamically, instead
  of using fixed template string. — Christopher Arndt <chris@chrisarndt.de>
([`7b42504`](https://github.com/OZI-Project/OZI.build/commit/7b4250408954e75a69335a918f55a54b7c942393))

* Use meson to run the dist and install commands

Meson has wrappers around the dist and install targets. These are used
in favor of the backend-specific instructions in order to be agnsotic.
([`1cbba41`](https://github.com/OZI-Project/OZI.build/commit/1cbba41fbb224d374925c57cba75581bd78efd9c))

* Use 'backend-path' standard mechanism instead of intreehooks

Fixes https://gitlab.com/thiblahute/mesonpep517/-/issues/2
([`98fa4b6`](https://github.com/OZI-Project/OZI.build/commit/98fa4b6a9e6ec0467247421628c644a90b780ef0))

* Port from pytoml to `toml`

As per the pytoml github repo:

> The pytoml project is no longer being actively maintained. Consider using the toml package instead.
([`0358f05`](https://github.com/OZI-Project/OZI.build/commit/0358f05d6b99672e3be0696cb672a9c0bc5661f4))

* Add a COPYING file

And license as Apache 2.0 as meson so we can move the code there without licensing issue

Fixes https://gitlab.com/thiblahute/mesonpep517/-/issues/3
([`187f872`](https://github.com/OZI-Project/OZI.build/commit/187f8720ca004114160b6a27bba5d519d3be219f))

## 0.1.9999996 (2020-07-15)


### Unknown


* Release 0.1.9999996
([`1d3d091`](https://github.com/OZI-Project/OZI.build/commit/1d3d091cc8bdbfeb7deec4571ad840807f4adc38))

* Mark as depending on setuptools

Working around https://github.com/mesonbuild/meson/issues/7443
([`bb1a4ff`](https://github.com/OZI-Project/OZI.build/commit/bb1a4ff23101237d0d0f311716cf442782e044fb))

* Fix spelling issue
([`be3e2be`](https://github.com/OZI-Project/OZI.build/commit/be3e2beeaa75c595a015b2a6440d7e3bd9d213f8))

* Fix some spelling
([`d3ca51c`](https://github.com/OZI-Project/OZI.build/commit/d3ca51c80a7960b71b2f8852c235d9269cf2e038))

* Minor fix in the scheme
([`ec5c73c`](https://github.com/OZI-Project/OZI.build/commit/ec5c73c837842c19c18945404228ad079d3034d9))

* Handle some wheel version incompatibilities
([`c85cfe7`](https://github.com/OZI-Project/OZI.build/commit/c85cfe7f3b79f82d6368436836e1617039d22993))

* Validate scheme
([`9fc3947`](https://github.com/OZI-Project/OZI.build/commit/9fc394744c079b4b053b09ae17e14762ee396c4b))

* Auto generate documentation
([`ef3e4b6`](https://github.com/OZI-Project/OZI.build/commit/ef3e4b6c2ac5813980962ffbb0a5434380a95c0f))

* Factor a Config class
([`891fa59`](https://github.com/OZI-Project/OZI.build/commit/891fa59c53e536e3b199faf0178406ef577989c2))

* Enhance failures logs
([`83af376`](https://github.com/OZI-Project/OZI.build/commit/83af3767b82fef8f9e203bd7113f1e023e546ba7))

* Better handle missing hotdoc
([`40d0f96`](https://github.com/OZI-Project/OZI.build/commit/40d0f96b17e29ebe1bacefbfe9d48c79967d3c25))

* Allow passing a PKG-INFO file directly in a 'pkg-config-file' key
([`1d28406`](https://github.com/OZI-Project/OZI.build/commit/1d28406c30d373194365e8f19ce011c04e7fa41b))

* Fix build with py3.5
([`900a8cf`](https://github.com/OZI-Project/OZI.build/commit/900a8cf15807c5d0d8ac1c812286da581cdc5f44))

* Fix displaying project description
([`cfd23a3`](https://github.com/OZI-Project/OZI.build/commit/cfd23a3f13fbefbf0a68672179a9392dc1f5e7c3))

* Build the doc

And add CI
([`f9ba791`](https://github.com/OZI-Project/OZI.build/commit/f9ba791e8f6e183bfdf6999804021dc11faf98b8))

* Some cleanup
([`6f80206`](https://github.com/OZI-Project/OZI.build/commit/6f80206ba58821322e82d32ffeed1f55f10fdbcb))

* Remove metdatas in meson, it is not merged yet
([`00bb1b8`](https://github.com/OZI-Project/OZI.build/commit/00bb1b8ec8a977194dd897e30a332278cc957fe7))

* Properly name wheels
([`c7f027e`](https://github.com/OZI-Project/OZI.build/commit/c7f027ec50d24cfe53d97e09ddcce86e6bbf29ed))

* Add entry-points support
([`16d542f`](https://github.com/OZI-Project/OZI.build/commit/16d542f3b29758527f7a3ba625b547eaa475f3d8))

* Fix licensing

Using the same as meson to make a potential merge simpler
([`4ffdf43`](https://github.com/OZI-Project/OZI.build/commit/4ffdf432277859596e6cb8586b33b6887ca6c3d0))

* Enhance metadata file
([`4f6d8eb`](https://github.com/OZI-Project/OZI.build/commit/4f6d8eb51b191e6721b527ff544a63499898a060))

* Add a basic readme and a simple relese file
([`22824c8`](https://github.com/OZI-Project/OZI.build/commit/22824c8d1d046b84f570646054d241161d4ac3c9))

* Fix pypi build
([`b1bbe8e`](https://github.com/OZI-Project/OZI.build/commit/b1bbe8e9f1ec0d30622a4d764fbffc031a48c141))

* Initial commit
([`9c52e8e`](https://github.com/OZI-Project/OZI.build/commit/9c52e8e5f1452d635cc45d59693487f761ff465e))
